Package: SelectSim
Title: Selected Events Linked by Evolutionary Conditions in Cancer
Version: 0.1.6
Authors@R: c(
    person("Arvind", "Iyer", , "ayalurarvind@gmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0002-8247-700X")),
    person("Marco", "Mina", , "marco.mina.85@gmail.com", role = "aut"),
    person("Miljan", "Petrovic", , "miljanpet93@gmail.com", role = c("aut", "cph")),
    person("Giovanni", "Ciriello", , "giovanni.ciriello@unil.ch", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0003-2021-8683"))
  )
Description: Implements the 'SelectSim' methodology for identifying patterns of
    co-occurrence and mutual exclusivity between functional genomic alterations
    in cancer cohorts. The package processes mutation annotation data, constructs
    alteration matrices, estimates expected alteration-pair frequencies, and
    quantifies deviations associated with selective interactions. The methodology
    is described in Iyer et al. (2026) <doi:10.1038/s41588-026-02661-4>.
License: MIT + file LICENSE
URL: https://csogroup.github.io/SelectSim/
BugReports: https://github.com/CSOgroup/SelectSim/issues
Depends: R (>= 3.5)
Imports: doParallel, doRNG, dplyr, foreach, ggplot2, ggpubr, ggridges,
        Matrix, parallel, Rcpp, Rfast, stats
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), tictoc
LinkingTo: Rcpp, RcppArmadillo
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
RoxygenNote: 8.0.0
Language: en-US
NeedsCompilation: yes
Packaged: 2026-07-12 07:29:57 UTC; arvindiyer
Author: Arvind Iyer [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-8247-700X>),
  Marco Mina [aut],
  Miljan Petrovic [aut, cph],
  Giovanni Ciriello [aut, cph] (ORCID:
    <https://orcid.org/0000-0003-2021-8683>)
Maintainer: Arvind Iyer <ayalurarvind@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-21 10:40:14 UTC

# Generated by roxygen2: do not edit by hand

export(GENIE_maf_schema)
export(TCGA_maf_schema)
export(add)
export(al.pairwise.alteration.stats)
export(al.stats)
export(am.pairwise.alteration.coverage)
export(am.pairwise.alteration.overlap)
export(am.stats)
export(am.weight.pairwise.alteration.overlap)
export(binary.yule)
export(effectSize)
export(estimateFDR2)
export(estimate_p_val)
export(estimate_pairwise_p)
export(filter_maf_column)
export(filter_maf_complex)
export(filter_maf_gene.name)
export(filter_maf_ignore)
export(filter_maf_missense)
export(filter_maf_mutation.type)
export(filter_maf_mutations)
export(filter_maf_sample)
export(filter_maf_schema)
export(filter_maf_truncating)
export(generateS)
export(generateW_block)
export(generateW_mean_tmb)
export(get.blocks)
export(interaction.table)
export(maf2gam)
export(mutation_type)
export(new.AL.general)
export(new.ALS)
export(new.AMS)
export(null_model_parallel)
export(obs_exp_scatter)
export(overlap_pair_extract)
export(r.am.pairwise.alteration.overlap)
export(r.effectSize)
export(retrieveOutliers)
export(ridge_plot_ed)
export(ridge_plot_ed_compare)
export(selectX)
export(stat_maf_column)
export(stat_maf_gene)
export(stat_maf_sample)
export(template.obj.gen)
export(theme_Publication)
export(w.r.am.pairwise.alteration.overlap)
import(doParallel)
import(doRNG)
import(foreach)
import(ggplot2)
import(ggpubr)
import(ggridges)
importFrom(Matrix,Matrix)
importFrom(Matrix,sparseMatrix)
importFrom(Matrix,t)
importFrom(Rcpp,sourceCpp)
importFrom(Rfast,rowSort)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,case_when)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,row_number)
importFrom(dplyr,ungroup)
importFrom(parallel,makeCluster)
importFrom(parallel,stopCluster)
importFrom(stats,as.dist)
importFrom(stats,density)
importFrom(stats,ecdf)
importFrom(stats,median)
importFrom(stats,runif)
importFrom(stats,setNames)
useDynLib(SelectSim, .registration = TRUE)

<!-- README.md is generated from README.Rmd. Please edit that file -->

# SelectSim <a href="https://csogroup.github.io/SelectSim/"><img src="man/figures/logo.png" align="right" height="138" alt="SelectSim website" /></a>

<!-- badges: start -->

[![R-CMD-check](https://github.com/CSOgroup/SelectSim/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/CSOgroup/SelectSim/actions/workflows/R-CMD-check.yaml)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.19680236.svg)](https://doi.org/10.5281/zenodo.19680236)
<!-- badges: end -->

SelectSim is an R package that infers evolutionary dependencies i.e
co-mutations and mutual exclusivities — between functional alterations
across cancer genomes. It estimates the expected co-mutation frequency
for each gene pair from individual mutation frequencies and per-sample
tumor mutation burden (TMB), then evaluates significance against a
simulation based null model.

<figure>
<img src="man/figures/SelectSim_method.png" alt="SelectSim Method" />
<figcaption aria-hidden="true">SelectSim Method</figcaption>
</figure>

The method accounts for heterogeneous tumor types, tissue specificities,
and distinct mutational processes through a covariate-aware weighting
scheme. Significance is assessed as a weighted effect size with
frequency-stratified FDR control generated via simulation.

This package accompanies the manuscript:

> Iyer A, Petrovic M, Sesia D, Nanni L, Mina M, Ciriello G (2026).
> Evolving patterns of co-mutations from tumor initiation to metastatic
> progression. *Nature Genetics*. DOI:
> [10.1038/s41588-026-02661-4](https://doi.org/10.1038/s41588-026-02661-4)

## Installation

You can install the development version of SelectSim from
[GitHub](https://github.com/CSOgroup/SelectSim) with:

``` r
# install.packages("pak")
pak::pak("CSOgroup/SelectSim")
```

For more details on installation refer to
[INSTALLATION](https://github.com/CSOgroup/SelectSim/blob/main/INSTALLATION.md).

## Quick start

``` r
library(SelectSim)
library(dplyr)

# Load the bundled TCGA LUAD example data
data(luad_run_data, package = "SelectSim")

# Run SelectSim (1 000 permutations, single core)
result <- selectX(
  M                = luad_run_data$M,
  sample.class     = luad_run_data$sample.class,
  alteration.class = luad_run_data$alteration.class,
  n.cores          = 1,
  min.freq         = 10,
  n.permut         = 1000,
  lambda           = 0.3,
  tau              = 1,
  maxFDR           = 0.25
)

# Significant evolutionary dependencies at FDR ≤ 0.25
result$result |> filter(nFDR2 <= 0.25) |> head()
```

For a full walkthrough see the [Introduction
vignette](https://csogroup.github.io/SelectSim/articles/introduction.html).

## Documentation

Full documentation and vignettes are available at
<https://csogroup.github.io/SelectSim/>.

## Citation

If you use SelectSim in your research, please cite:

> Iyer A, Petrovic M, Sesia D, Nanni L, Mina M, Ciriello G (2026).
> Evolving patterns of co-mutations from tumor initiation to metastatic
> progression. *Nature Genetics*. DOI:
> [10.1038/s41588-026-02661-4](https://doi.org/10.1038/s41588-026-02661-4)

You can also run `citation("SelectSim")` inside R for a formatted
reference.

## Contact

- For bugs or feature requests, please use the [issue
  tracker](https://github.com/CSOgroup/SelectSim/issues).
- For other questions, contact Prof. Giovanni Ciriello
  (<giovanni.ciriello@unil.ch>) or Arvind Iyer
  (<ayalurarvind@gmail.com>).

###
# Author  : Arvind Iyer, Miljan Petrovic
# Project : SelectSim
# Desc    : Main file which to run the SelecSim algoritm via calling selectX function to create alteration object with background model and funtion to generate the table.
# Version : 0.1.6
# Notes:
# - Better Error message and running text
# - Edge case: When sample size in less than 2 there is error in computation (need to fix a number to do this analysis)
# - parallel::makeCluster(2, setup_strategy = "sequential") a possible fix to remove the error of connection problem (https://github.com/rstudio/rstudio/issues/6692)
# - Try to fix the parallel processing issuses
###

###
#' SelectX main function from SelectSim to create alteration object with background model
#'
#' @description
#' `selectX()` takes a list object which consist of genome alteration matrix and tumor mutation burden.
#'
#' @import foreach
#' @import doParallel
#' @importFrom  stats as.dist
#' @importFrom  stats density
#' @importFrom  stats ecdf
#' @importFrom  stats runif
#' @importFrom  stats setNames
#' @param M a list data object which consist of gams and tmbs.
#' @param sample.class sample covariates as named list.
#' @param alteration.class alteration covariates as named list.
#' @param n.cores no of cores.
#' @param min.freq number of samples for features to be at least mutated in.
#' @param n.permut number of simulations.
#' @param lambda lambda parameter.
#' @param tau tau (fold change) parameter.
#' @param folder folder path to store the results.
#' @param save.object store the SelectX object.
#' @param verbose print the time and each steps.
#' @param estimate_pairwise Compute pairwise p-value
#' @param maxFDR FDR value
#' @param seed a random seed
#' @return result  a SelectSim object with background model and other info along with result table
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' result <- selectX(
#'   M                = luad_run_data$M,
#'   sample.class     = luad_run_data$sample.class,
#'   alteration.class = luad_run_data$alteration.class,
#'   n.cores          = 1,
#'   min.freq         = 10,
#'   n.permut         = 10,
#'   verbose          = FALSE
#' )
#' head(result$result)
#' }
#'
#' @export
selectX <- function(M,
                    sample.class,
                    alteration.class,
                    n.cores = 1,
                    min.freq = 10,
                    n.permut = 1000,
                    lambda = 0.3,
                    tau = 1,
                    save.object = FALSE,
                    folder = "./",
                    verbose = TRUE,
                    estimate_pairwise = FALSE,
                    maxFDR = 0.25,
                    seed = 42) {
  set.seed(seed)
  use_tictoc <- verbose && requireNamespace("tictoc", quietly = TRUE)
  if (verbose) {
    print(paste("#### Creating SelectSim object ####"))
    if (use_tictoc) tictoc::tic("Total time taken:")
  }

  if (verbose) {
    print(paste("Step1-> Parsing and Filtering GAM..."))
    if (use_tictoc) tictoc::tic("Time:")
  }
  al <- new.AL.general(M, alteration.class, sample.class, min.freq, verbose)
  if (verbose) {
    print(paste("-> Alteration Landscape object created"))
    if (use_tictoc) tictoc::toc()
  }

  if (verbose) {
    print(paste("Step2-> Generating Template object..."))
    if (use_tictoc) tictoc::tic("Time:")
  }
  temp.data <- template.obj.gen(al)
  if (verbose) {
    print(paste("-> Template object created"))
    if (use_tictoc) tictoc::toc()
  }

  if (verbose) {
    print(paste("Step3-> Generating sample weight matrix..."))
    if (use_tictoc) tictoc::tic("Time:")
  }
  W <- generateW_block(al, lambda, tau)
  if (verbose) {
    print(paste("-> Weight Matrix created"))
    if (use_tictoc) tictoc::toc()
  }

  if (verbose) {
    print(paste("Step4-> Generating null model..."))
    if (use_tictoc) tictoc::tic("Time:")
  }
  sim <- null_model_parallel(al, temp.data$temp_mat, W$W, n.cores, n.permut)
  obj <- list("al" = al, "W" = W, "T" = temp.data, "null" = sim, "nSim" = n.permut)
  if (verbose) print(paste("-> Removing the outliers matrix from null model..."))
  outliers <- retrieveOutliers(obj = obj, nSim = n.permut)
  if (length(which(outliers)) == 0) {
    if (verbose) print(paste("Removed null-matrix:", length(which(outliers)), sep = " "))
    obj$nSim <- n.permut
  } else {
    if (verbose) print(paste(" Removed null-matrix:", length(which(outliers)), sep = " "))
    obj$null <- obj$null[which(!outliers)]
    if (verbose) print(paste(" Updated the null-model and nSim variables..."))
    obj$nSim <- length(which(!outliers))
  }
  if (verbose) {
    if (use_tictoc) tictoc::toc()
    print(paste("-> Null model generated"))
    print(paste("### SelectSim object created ###"))
  }

  if (verbose) {
    print(paste("#### Computing EDs on the dataset ####"))
    if (use_tictoc) tictoc::tic("Time:")
  }
  al <- obj$al
  als <- al.stats(obj)
  alp <- al.pairwise.alteration.stats(obj, als, do.blocks = FALSE)
  als[["alteration.pairwise"]] <- alp
  als[["alteration.pairwise"]]$sample.blocks <- NULL
  for (i in names(als$sample.blocks)) als$sample.blocks[[i]][["alteration.pairwise"]] <- alp$sample.blocks[[i]]
  obs.co <- as.matrix(als$alteration.pairwise$overlap)
  wobs.co <- as.matrix(als$alteration.pairwise$w_overlap)
  robs.co <- r.am.pairwise.alteration.overlap(null = obj$null, n.permut = obj$nSim, n.cores = 1)
  wrobs.co <- w.r.am.pairwise.alteration.overlap(null = obj$null, W = obj$W$W, n.permut = obj$nSim, n.cores = 1)
  selectX_result <- interaction.table(al, als, obs.co, wobs.co, robs.co, wrobs.co,
    null = obj$null, maxFDR = maxFDR, n.cores = 1,
    estimate_pairwise = estimate_pairwise, n.permut = obj$nSim
  )
  obj$robs.co <- robs.co
  obj$wrobs.co <- wrobs.co
  if (verbose) {
    if (use_tictoc) tictoc::toc()
    print(paste("#### EDs computed ####"))
  }

  if (use_tictoc) tictoc::toc()

  if (save.object) {
    saveRDS(obj, file = paste(folder, "selectsim_object.rds", sep = ""))
    saveRDS(selectX_result, file = paste(folder, "selectsim_results.rds", sep = ""))
  }
  return(list(obj = obj, result = selectX_result))
}

## usethis namespace: start
#' @importFrom Rcpp sourceCpp
## usethis namespace: end
NULL

## usethis namespace: start
#' @useDynLib SelectSim, .registration = TRUE
## usethis namespace: end
NULL

test_that("selectX() from SelectSim generates same results on LUAD dataset", {
  # Load the dataset
  data(luad_run_data, package = "SelectSim")
  data(luad_result, package = "SelectSim")
  # result of applying function
  outdat <- selectX(
    M = luad_run_data$M,
    sample.class = luad_run_data$sample.class,
    alteration.class = luad_run_data$alteration.class,
    n.cores = 1,
    min.freq = 10,
    n.permut = 1000,
    lambda = 0.3,
    tau = 1,
    save.object = FALSE,
    verbose = FALSE,
    estimate_pairwise = FALSE,
    maxFDR = 0.25
  )

  # Check if the result dataframe is same
  expect_true(identical(dim(luad_result), dim(outdat$result)))
  # Check if the number of signficant pairs is the same
  true_p <- nrow(luad_result[luad_result$FDR == TRUE, ])
  test_p <- nrow(outdat$result[outdat$result$FDR == TRUE, ])
  expect_equal(true_p, test_p)
})
#> Test passed 😀

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## -----------------------------------------------------------------------------
library(SelectSim)
library(dplyr)
if (requireNamespace("tictoc", quietly = TRUE)) library(tictoc)
## Load the data provided with the package
data(luad_maf, package = "SelectSim")
data(oncokb_genes, package = "SelectSim")
data(oncokb_truncating_genes, package = "SelectSim")
data(variant_catalogue, package = "SelectSim")

## -----------------------------------------------------------------------------
# Check the MAF
dim(luad_maf)

## -----------------------------------------------------------------------------
input_maf <- luad_maf
print(paste('##### Number of lines ####',nrow(input_maf),sep="->"))
genes_to_consider =  oncokb_genes
print(paste('##### Number of genes ####',length(genes_to_consider),sep="->"))

## -----------------------------------------------------------------------------
mutation_type = list(
      'ignore' = c("Silent","Intron","RNA","3'UTR","5'UTR","5'Flank","3'Flank","IGR"),
      'truncating'= c('Frame_Shift_Del','Frame_Shift_Ins','In_Frame_Del','In_Frame_Ins','Nonsense_Mutation','Nonstop_Mutation','Splice_Region','Splice_Site','Translation_Start_Site'),
      'missense' = c('Missense_Mutation')
)
custom_maf_schema = list(
    'name' = 'custom_maf',
    'column' = list(
          'gene' = 'Hugo_Symbol'
        , 'gene.name' = 'Hugo_Symbol'
        , 'sample' = 'sample'
        , 'sample.name' = 'sample'
        , 'mutation.type' = 'Variant_Classification'
        , 'mutation' = 'HGVSp_Short'
        ),
        'mutation.type' = mutation_type
)

## -----------------------------------------------------------------------------
mut_samples = unique(input_maf[, custom_maf_schema$column$sample])
print(paste('##### Number of samples ####',length(mut_samples),sep="->"))

## -----------------------------------------------------------------------------
maf_genes = filter_maf_gene.name(input_maf, genes = genes_to_consider, gene.col = custom_maf_schema$column$gene)
print(paste('##### Number of lines ####',nrow(maf_genes),sep="->"))

## -----------------------------------------------------------------------------
# Creating Truncating GAM
if (requireNamespace("tictoc", quietly = TRUE)) tictoc::tic('##### Creating Truncating GAM ####')
    maf_trunc = filter_maf_truncating(maf_genes,genes=oncokb_truncating_genes, custom_maf_schema)
    input_maf_trunc<-filter_maf_truncating(input_maf, custom_maf_schema)
    truncating_tmb <- data.frame('sample'=mut_samples,'mutation'=rep(0,length(mut_samples)))
    rownames(truncating_tmb)<-mut_samples
    temp <- input_maf_trunc %>% count(sample)
    rownames(temp)<-temp$sample
    truncating_tmb[intersect(truncating_tmb$sample,temp$sample),]$mutation <-temp[intersect(truncating_tmb$sample,temp$sample),'n']
    tcga_truc_gam = maf2gam(maf_trunc,
                     sample.col = custom_maf_schema$column$sample,
                     gene.col = custom_maf_schema$column$gene,
                     value.var = 'Variant_Classification',
                     samples = mut_samples,
                     genes = genes_to_consider,
                     fun.aggregate = length,
                     binarize=TRUE,
                     fill=0)
    truncating_data <- list('gam'=tcga_truc_gam,
                            'tmb'=truncating_tmb)
if (requireNamespace("tictoc", quietly = TRUE)) tictoc::toc()

## -----------------------------------------------------------------------------
# Creating Missense GAM
if (requireNamespace("tictoc", quietly = TRUE)) tictoc::tic('##### Creating Missense GAM ####')
    maf_valid = filter_maf_schema(input_maf,
                             schema = custom_maf_schema,
                             column = 'mutation.type',
                             values = custom_maf_schema[['mutation.type']][['ignore']],
                             inclusive = FALSE)
    missense_maf<-filter_maf_mutation.type(input_maf,
                                      variants = 'Missense_Mutation',
                                      variant.col = custom_maf_schema$column$mutation.type)
    missense_tmb <- data.frame('sample'=mut_samples,'mutation'=rep(0,length(mut_samples)))
    rownames(missense_tmb)<-mut_samples
    temp <- missense_maf %>% count(sample) 
    rownames(temp)<-temp$sample
    missense_tmb[intersect(missense_tmb$sample,temp$sample),]$mutation <-temp[intersect(missense_tmb$sample,temp$sample),'n']
    t_m = substr(maf_valid[[custom_maf_schema$column$mutation]],3,1000)
    t_m1 =  gsub('[A-Z]*$', '', t_m)
    maf_valid$HGVSp_Short_fixed = t_m1
    maf_hotspot = filter_maf_mutations(maf_valid,
                                  variant_catalogue,
                                  maf.col = c(custom_maf_schema$column$gene, 'HGVSp_Short_fixed'),
                                  values.col = c('gene', 'mut'))

    missense_tcga_gam = maf2gam(maf_hotspot,
                     sample.col = custom_maf_schema$column$sample,
                     gene.col = custom_maf_schema$column$gene,
                     value.var = 'Variant_Classification',
                     samples = mut_samples,
                     genes = genes_to_consider,
                     fun.aggregate = length,
                     binarize=TRUE,
                     fill=0)
    missesne_data <- list('gam'=missense_tcga_gam,
                          'tmb'=missense_tmb)

if (requireNamespace("tictoc", quietly = TRUE)) tictoc::toc()

## -----------------------------------------------------------------------------
gene_to_take <- colnames(missesne_data$gam)
order <- rownames(missesne_data$gam)

data <-list('M'=list('missense'=t(missesne_data$gam[order,gene_to_take]),
                     'truncating'=t(truncating_data$gam[rownames(missesne_data$gam[order,]),gene_to_take])),
            'tmb'=list('missense'=missesne_data$tmb[order,],
                       'truncating'=truncating_data$tmb[order,]))

alteration_covariates <- rep('MUT',ncol(missesne_data$gam[order,gene_to_take]))
names(alteration_covariates)<-colnames(missesne_data$gam[order,gene_to_take])
sample_covariates<-rep('LUAD',length(order))
names(sample_covariates)<-order
run_data <- list('M'=data,'sample.class' = sample_covariates,'alteration.class' = alteration_covariates)
str(run_data)

## -----------------------------------------------------------------------------
# Print the sessionInfo
sessionInfo()

###
# Author  : Arvind Iyer, Miljan Petrovic
# Project : SelectSim
# Desc    : Implementation of SelectSim algorithm
# Version : 0.1.6
###

#' Create an Alteration Landscape (AL) object
#'
#' Builds an Alteration Landscape object from a list of genome alteration matrices
#' and their corresponding tumor mutation burdens.
#'
#' @param am A named list with two required elements: \code{M} (a named list of binary
#'   alteration matrices, each genes x samples) and \code{tmb} (a named list of data
#'   frames, one per matrix in \code{M}, each with columns \code{sample} and
#'   \code{mutation}). The names of \code{M} and \code{tmb} must match. All matrices
#'   in \code{M} must have identical row and column names.
#' @param feat.covariates Named character vector of alteration-type annotations, one
#'   entry per feature (gene). Names must match rownames of the matrices in \code{M}.
#'   If \code{NULL}, all features are labelled \code{"MUT"}.
#' @param sample.covariates Named character vector of sample-type annotations, one
#'   entry per sample. Names must match colnames of the matrices in \code{M}. If
#'   \code{NULL}, all samples are labelled \code{"sample"}.
#' @param min.freq Minimum number of samples a gene must be mutated in (strictly
#'   greater than) to be retained. Features with \code{rowSums <= min.freq} are
#'   dropped.
#' @param verbose Logical; print progress messages.
#' @return An Alteration Landscape (AL) object (list of class \code{"AL"}) containing
#'   the filtered alteration matrices, TMB vectors, and covariate assignments.
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' al <- new.AL.general(
#'   am               = luad_run_data$M,
#'   feat.covariates  = luad_run_data$alteration.class,
#'   sample.covariates = luad_run_data$sample.class,
#'   min.freq         = 10
#' )
#' }
#'
#' @export
new.AL.general <- function(am,
                           feat.covariates = NULL,
                           sample.covariates = NULL,
                           min.freq,
                           verbose = FALSE) {
  if (is.null(am$M)) stop("am$M is NULL: provide a named list of alteration matrices.")
  if (is.null(am$tmb)) stop("am$tmb is NULL: provide a named list of TMB data frames.")
  if (!all(names(am$M) %in% names(am$tmb))) {
    stop("All names in am$M must have a matching entry in am$tmb.")
  }
  if (!all(sapply(am$tmb, function(t) all(c("sample", "mutation") %in% colnames(t))))) {
    stop("Each data frame in am$tmb must have 'sample' and 'mutation' columns.")
  }
  if (length(am$M) > 1) {
    ref_rows <- rownames(am$M[[1]])
    ref_cols <- colnames(am$M[[1]])
    if (!all(sapply(am$M[-1], function(m) identical(rownames(m), ref_rows)))) {
      stop("All matrices in am$M must have identical rownames.")
    }
    if (!all(sapply(am$M[-1], function(m) identical(colnames(m), ref_cols)))) {
      stop("All matrices in am$M must have identical colnames.")
    }
  }

  # create the alteration landscape object
  al <- list("am" = list())
  # Create a full gam
  al$am[["full"]] <- matrix(0, nrow = nrow(am$M[[1]]), ncol = ncol(am$M[[1]]))
  # Keep the order of rownames and colnames as in first gam.
  row.order <- sort(rownames(am$M[[1]])) # fixed gene ordering issuses
  col.order <- colnames(am$M[[1]])
  for (i in names(am$M)) {
    al$am[[i]] <- as.matrix(am$M[[i]][row.order, col.order])
    al$am[["full"]] <- al$am[["full"]] + as.matrix(am$M[[i]][row.order, col.order])
  }
  al$am[["full"]][al$am[["full"]] >= 1] <- 1 # binarize

  # Filtering steps
  # Filtering the al to keep only genes mutated with min.freq
  if (verbose) {
    print(paste("Number of features:", nrow(al$am$full), sep = " "))
  }
  feat <- rownames(al$am$full[rowSums(al$am$full) > min.freq, ])
  for (i in names(al$am)) {
    al$am[[i]] <- al$am[[i]][feat, ]
  }
  if (verbose) {
    print(paste("Number of features after filtering:", nrow(al$am$full), sep = " "))
  }
  # Set the feature and sample co-varaites
  al$alterations <- list()
  al$samples <- list()
  if (is.null(feat.covariates)) {
    al$alterations$alteration.class <- rep("MUT", nrow(al$am[[1]]))
    names(al$alterations$alteration.class) <- rownames(al$am[[1]])
  } else {
    al$alterations$alteration.class <- feat.covariates
  }
  if (is.null(sample.covariates)) {
    al$samples$sample.class <- rep("sample", ncol(al$am[[1]]))
    names(al$samples$sample.class) <- colnames(al$am[[1]])
  } else {
    al$samples$sample.class <- sample.covariates
  }
  # set the tumor mutation burden vector
  al$tmb <- list()
  for (i in names(am$M)) {
    al$tmb[[i]] <- am$tmb[[i]]
  }
  al$tmb[["total"]] <- c(rep(0, ncol(am$M[[1]])))
  for (i in names(am$tmb)) {
    al$tmb[["total"]] <- al$tmb[["total"]] + am$tmb[[i]][, c("mutation")]
  }
  names(al$tmb$total) <- am$tmb[[1]]$sample

  class(al) <- "AL"
  return(al)
}

#' Get sample/alteration blocks
#'
#' @param al The alteration landscape
#' @return Classification of samples and alterations in blocks.
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' al <- new.AL.general(luad_run_data$M,
#'                      feat.covariates  = luad_run_data$alteration.class,
#'                      sample.covariates = luad_run_data$sample.class,
#'                      min.freq = 10)
#' get.blocks(al)
#' }
#'
#' @export
get.blocks <- function(al) {
  if (is.null(al$alterations$alteration.class)) {
    al$alterations$alteration.class <- rep("MUT", nrow(al$am[[1]]))
    names(al$alterations$alteration.class) <- rownames(al$am[[1]])
  }
  if (is.null(al$samples$sample.class)) {
    al$samples$sample.class <- rep("sample", ncol(al$am[[1]]))
    names(al$samples$sample.class) <- colnames(al$am[[1]])
  }
  alteration.class <- al$alterations$alteration.class[rownames(al$am$full)]
  sample.class <- al$samples$sample.class[colnames(al$am$full)]
  feature.blocks <- lapply(unique(alteration.class), function(x) which(alteration.class == x))
  names(feature.blocks) <- unique(alteration.class)
  sample.blocks <- lapply(unique(sample.class), function(x) which(sample.class == x))
  names(sample.blocks) <- unique(sample.class)
  missing_rows <- which(!1:nrow(al$am$full) %in% unlist(feature.blocks))
  missing_cols <- which(!1:ncol(al$am$full) %in% unlist(sample.blocks))
  return(list(
    "sample.blocks" = sample.blocks,
    "alteration.blocks" = feature.blocks,
    "missing.samples" = missing_cols,
    "missing.alterations" = missing_rows
  ))
}

#' Generate S matrix
#'
#' @param gam the gam with genes*samples
#' @param sample.weights the samples weights
#' @param upperBound clip the values greater than 1 to keep it bounded between 0 to 1
#' @return S the S matrix
#'
#' @examples
#' gam <- matrix(c(0,1,1,0,1,1), nrow = 2,
#'               dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
#' generateS(gam, sample.weights = c(s1 = 1, s2 = 1, s3 = 1))
#'
#' @export
generateS <- function(gam,
                      sample.weights,
                      upperBound = 1) {
  gene.freq <- as.matrix(rowSums(gam) / ncol(gam), ncol = 1)
  tmb.weight <- (as.matrix(sample.weights, nrow = 1))
  sim.gam <- tcrossprod(gene.freq, tmb.weight)
  colnames(sim.gam) <- colnames(gam)
  sim.gam[sim.gam > 1] <- upperBound
  return(sim.gam)
}


#' Generate the template matrix
#'
#' Computes the expected mutation probability matrices (one per GAM type, per
#' sample block) used as the simulation background in \code{null_model_parallel}.
#'
#' @param al Alteration landscape object
#' @return A list with \code{template.obj} (per-block S matrices) and
#'   \code{temp_mat} (full concatenated template matrices, one per GAM type).
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' al <- new.AL.general(luad_run_data$M,
#'                      feat.covariates  = luad_run_data$alteration.class,
#'                      sample.covariates = luad_run_data$sample.class,
#'                      min.freq = 10)
#' template.obj.gen(al)
#' }
#'
#' @export
template.obj.gen <- function(al) {
  temp.al <- list()
  category <- c()
  for (name in names(al$am)) {
    if (name == "full") {} else {
      temp.al[[name]] <- list()
      category <- c(category, name)
    }
  }
  template_list <- list()
  for (name in category) {
    template_list[[name]] <- NULL
  }
  blocks <- get.blocks(al)
  for (block in names(blocks$sample.blocks)) {
    for (i in c(1:length(category))) {
      name <- category[i]
      samples <- names(blocks$sample.blocks[[block]])
      sample.weights <- length(samples) * al$tmb[[name]][samples, "mutation"] / sum(al$tmb[[name]][samples, "mutation"])
      S <- generateS(al$am[[name]][, samples], sample.weights)
      temp.al[[name]][[block]] <- S
      temp.al[[name]][[paste(block, "_weight", sep = "")]] <- sample.weights
      template_list[[name]] <- cbind(template_list[[name]], S)
    }
  }
  return(list("template.obj" = temp.al, "temp_mat" = template_list))
}


#' Generate sample weight matrix from TMB values
#'
#' @description
#' Computes a per-sample weight matrix based on the ratio of each sample's TMB to
#' the expected (mean) TMB. Samples with higher-than-expected TMB receive lower
#' weights via a penalty \code{lambda}, controlled by the fold-change threshold
#' \code{tau}.
#'
#' @param tmb Numeric vector of per-sample TMB values.
#' @param mean_tmb Numeric scalar; the reference (expected) TMB used to compute
#'   fold changes.
#' @param ngenes Integer; number of genes (rows) in the output weight matrix.
#' @param lambda Numeric; weight penalty factor. Higher values penalise
#'   high-TMB samples more strongly (default 0.3).
#' @param tau Numeric; fold-change threshold below which no penalty is applied
#'   (default 1).
#' @param discrete Logical; if \code{TRUE}, fold changes are rounded up before
#'   applying the penalty (default \code{TRUE}).
#' @return Numeric matrix of sample weights (ngenes x length(tmb)).
#'
#' @examples
#' tmb      <- c(s1 = 10, s2 = 50, s3 = 20)
#' mean_tmb <- 25
#' generateW_mean_tmb(tmb, mean_tmb, ngenes = 3)
#'
#' @export
generateW_mean_tmb <- function(tmb,
                               mean_tmb,
                               ngenes,
                               lambda = 0.3,
                               tau = 1,
                               discrete = TRUE) {
  exp.tmb <- mean_tmb
  tmb.FC <- tmb / exp.tmb
  tmb.FC[tmb.FC <= tau] <- tau
  w <- 1 / (1 + lambda * (ceiling(tmb.FC) - tau))
  if (!discrete) {
    w <- 1 / (1 + lambda * (tmb.FC - tau))
  }
  W <- matrix(rep(w, ngenes), nrow = ngenes, byrow = TRUE)
  return(W)
}


#' Generate block-aware sample weight matrix
#'
#' @description
#' Computes a sample weight matrix that accounts for sample-class covariates
#' (blocks). Within each block the reference TMB is the block median; the
#' overall reference used by \code{generateW_mean_tmb} is the mean of those
#' block medians.
#'
#' @param al Alteration landscape object (from \code{new.AL.general}).
#' @param lambda Numeric penalty factor for the weight computation.
#' @param tau Numeric fold-change threshold below which no penalty is applied.
#' @return List with \code{W_block} (per-block weight matrices), \code{W} (full
#'   concatenated weight matrix), \code{W_median} (per-block median TMBs), and
#'   \code{mean_TMB} (mean of block medians).
#'
#' @importFrom  stats median
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' al <- new.AL.general(luad_run_data$M,
#'                      feat.covariates  = luad_run_data$alteration.class,
#'                      sample.covariates = luad_run_data$sample.class,
#'                      min.freq = 10)
#' generateW_block(al, lambda = 0.3, tau = 1)
#' }
#'
#' @export
generateW_block <- function(al, lambda, tau) {
  blocks <- get.blocks(al)
  W <- list()
  W_mtx <- NULL
  median_TMB <- list()
  mean_TMB <- 0
  # Mean of medians of tmb
  for (block in names(blocks$sample.blocks)) {
    samples <- names(blocks$sample.blocks[[block]])
    exp.tmb <- median(al$tmb$total[samples])
    median_TMB[[block]] <- exp.tmb
    mean_TMB <- mean_TMB + exp.tmb
  }
  mean_TMB <- mean_TMB / length(names(blocks$sample.blocks))
  for (block in names(blocks$sample.blocks)) {
    samples <- names(blocks$sample.blocks[[block]])
    W[[block]] <- generateW_mean_tmb(al$tmb$total[samples], mean_TMB, nrow(al$am$full), lambda = lambda, tau = tau)
    colnames(W[[block]]) <- samples
    rownames(W[[block]]) <- rownames(al$am$full)
    W_mtx <- cbind(W_mtx, W[[block]])
  }
  return(list("W_block" = W, "W" = W_mtx, "W_median" = median_TMB, "mean_TMB" = mean_TMB))
}

#' Generating the null_simulation matrix
#'
#' @import doParallel
#' @importFrom parallel makeCluster stopCluster
#' @importFrom Rfast rowSort
#' @import doRNG
#' @param al Alteration landscape object
#' @param temp_mat template matrices
#' @param W weight matrix
#' @param n.cores Number of cores
#' @param n.permut Number of simulations
#' @param seed Random seed
#' @return List of simulated binary matrices (one per permutation)
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' al       <- new.AL.general(luad_run_data$M,
#'                            feat.covariates  = luad_run_data$alteration.class,
#'                            sample.covariates = luad_run_data$sample.class,
#'                            min.freq = 10)
#' temp_obj <- template.obj.gen(al)
#' W        <- generateW_block(al, lambda = 0.3, tau = 1)
#' sims     <- null_model_parallel(al, temp_obj$temp_mat, W$W,
#'                                 n.cores = 1, n.permut = 10)
#' length(sims)
#' }
#'
#' @export
null_model_parallel <- function(al,
                                temp_mat,
                                W,
                                n.cores = 1,
                                n.permut,
                                seed = 42) {
  `%dopar%` <- foreach::`%dopar%`
  `%do%` <- foreach::`%do%`
  # Set RNG kind and seed for reproducibility
  RNGkind(kind = "Mersenne-Twister", normal.kind = "Inversion", sample.kind = "Rejection")
  set.seed(seed)
  simulationStep <- function(template, total_mut) {
    S <- template
    nvalues <- nrow(S) * ncol(S)
    r <- matrix(runif(nvalues, min = 0, max = 1), nrow = nrow(S), ncol = ncol(S))
    test <- S - r
    rownames(r) <- rownames(S)
    colnames(r) <- colnames(S)
    return(test)
  }

  combine <- function(residuals, residuals_sort, val, index) {
    return(residuals[index, ] >= residuals_sort[index, ][val[index]])
  }

  simulationFixedOnes <- function(al, temp_mat, W) {
    exp <- matrix(0, nrow = nrow(W), ncol = ncol(W))
    gam_names <- names(al$am)
    gam_incidence <- list()
    k <- 1
    for (name in gam_names) {
      if (name == "full") {} else {
        gam_incidence[[k]] <- sum(al$am[[name]])
        k <- k + 1
      }
    }
    residuals <- list()
    for (i in 1:length(temp_mat)) {
      S <- temp_mat[[i]]
      test <- simulationStep(template = S, total_mut = gam_incidence[[i]])
      residuals[[i]] <- test
    }
    residual_mtx <- Reduce(pmax, residuals)
    residual_mtx_sort <- Rfast::rowSort(residual_mtx, descending = TRUE)
    temp <- lapply(seq_len(nrow(al$am$full)), function(i) {
      combine(residual_mtx, residual_mtx_sort, rowSums(al$am$full), i)
    })
    exp <- do.call(rbind, temp) * 1
    rownames(exp) <- rownames(al$am$full)
    return(exp)
  }


  if (n.cores > 1) {
    log_file <- tempfile(pattern = "gen.random.am_", fileext = ".log")
    cl <- parallel::makeCluster(n.cores, outfile = log_file)
    doParallel::registerDoParallel(cl)
    on.exit({
      parallel::stopCluster(cl)
      foreach::registerDoSEQ()
      unlink(log_file)
      add <- TRUE
    })
    registerDoRNG(seed)
    randomMs <- foreach::foreach(i = 1:n.permut) %dopar% simulationFixedOnes(al, temp_mat, W)
    return(randomMs)
  } else {
    set.seed(seed)
    foreach::registerDoSEQ()
    registerDoRNG(seed)
    randomMs <- foreach(i = 1:n.permut) %do% simulationFixedOnes(al, temp_mat, W)
    return(randomMs)
  }
}

#' Identify outlier null-model matrices
#'
#' Flags simulations whose mean per-gene and per-sample deviation from the
#' observed counts falls in the top 10%, indicating numerical instability.
#' These are removed before computing effect sizes to prevent them from
#' inflating the null distribution.
#'
#' @param obj SelectX object (list with al and null fields)
#' @param nSim Number of simulations in the null model
#' @return Logical vector; TRUE for each null matrix flagged as an outlier.
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' result <- selectX(M = luad_run_data$M,
#'                   sample.class = luad_run_data$sample.class,
#'                   alteration.class = luad_run_data$alteration.class,
#'                   n.cores = 1, min.freq = 10, n.permut = 10,
#'                   verbose = FALSE)
#' outliers <- retrieveOutliers(result$obj, nSim = result$obj$nSim)
#' sum(outliers)
#' }
#'
#' @export
retrieveOutliers <- function(obj, nSim = 1000) {
  gnMut <- matrix(0, nrow = nrow(obj$al$am$full), ncol = nSim)
  snMut <- matrix(0, nrow = ncol(obj$al$am$full), ncol = nSim)
  for (i in 1:nSim) {
    gnMut[, i] <- rowSums(obj$null[[i]])
    snMut[, i] <- colSums(obj$null[[i]])
  }
  rgn <- gnMut - rowSums(obj$al$am$full)
  rsn <- snMut - colSums(obj$al$am$full)
  mean.gn <- apply(abs(rgn), 2, mean)
  mean.sn <- apply(abs(rsn), 2, mean)
  dev <- mean.gn + mean.sn
  dev2 <- sort(dev)
  maxcut <- dev2[round(0.90 * length(dev2))]
  outliers <- dev >= maxcut
  return(outliers)
}

#' Lung adenocarcinoma from TCGA cohort as SelectSim run object
#'
#' Preprocessed TCGA LUAD data ready to pass directly to \code{selectX()}.
#'
#' @docType data
#' @keywords datasets
#' @name luad_run_data
#' @usage data(luad_run_data)
#' @format A named list with four elements:
#' \describe{
#'   \item{M}{A named list containing:
#'     \describe{
#'       \item{M}{A named list of binary alteration matrices (genes x samples),
#'         one per alteration type (e.g., \code{missense}, \code{truncating}).}
#'       \item{tmb}{A named list of data frames, one per alteration type, each
#'         with columns \code{sample} (character) and \code{mutation} (integer
#'         TMB count).}
#'     }
#'   }
#'   \item{sample.class}{Named character vector of sample-type annotations
#'     (length = number of samples). Names are sample IDs.}
#'   \item{alteration.class}{Named character vector of alteration-type annotations
#'     (length = number of genes). Names are gene symbols.}
#' }
#'
#' @return A named list containing preprocessed LUAD input data for
#'   \code{selectX()}.
#' @examples
#' data(luad_run_data)
#' names(luad_run_data)
#' str(luad_run_data, max.level = 1)
NULL


#' Lung adenocarcinoma from TCGA cohort as SelectSim run results
#'
#' Result of LUAD generated by SelectSim with SelectSim run done at min.freq=10.
#'
#'
#' @docType data
#' @keywords datasets
#' @name luad_result
#' @usage data(luad_result)
#' @format A data frame
#'
#' @return A data frame containing SelectSim results for the LUAD cohort.
#' @examples
#' data(luad_result)
#' dim(luad_result)
#' head(luad_result)
NULL



#' Lung adenocarcinoma MAF from TCGA cohort 
#'
#' MAF file of LUAD from TCGA
#'
#'
#' @docType data
#' @keywords datasets
#' @name luad_maf
#' @usage data(luad_maf)
#' @format A data frame
#'
#' @return A data frame containing TCGA LUAD mutation data.
#' @examples
#' data(luad_maf)
#' dim(luad_maf)
#' head(luad_maf)
NULL


#' OncoKB v3.9 cancer genes
#'
#' cancer genes list
#'
#'
#' @docType data
#' @keywords datasets
#' @name oncokb_genes
#' @usage data(oncokb_genes)
#' @format A list
#'
#' @return An object containing cancer-associated genes annotated by OncoKB.
#' @examples
#' data(oncokb_genes)
#' length(oncokb_genes)
#' head(oncokb_genes)
NULL


#' OncoKB v3.9 cancer genes consider for truncating mutations
#'
#' cancer genes list consider for truncating mutations
#'
#'
#' @docType data
#' @keywords datasets
#' @name oncokb_truncating_genes
#' @usage data(oncokb_truncating_genes)
#' @format A list
#'
#' @return An object containing genes considered for truncating-mutation analyses.
#' @examples
#' data(oncokb_truncating_genes)
#' length(oncokb_truncating_genes)
#' head(oncokb_truncating_genes)
NULL


#' OncoKB v3.9 cancer genes
#'
#' A dataframe cancer genes with missense mutation annotations
#'
#'
#' @docType data
#' @keywords datasets
#' @name variant_catalogue
#' @usage data(variant_catalogue)
#' @format A data frame
#'
#' @return A data frame containing cancer-gene and variant annotations.
#' @examples
#' data(variant_catalogue)
#' dim(variant_catalogue)
#' head(variant_catalogue)
NULL

# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

rcpp_overlap <- function(v, t = 1L) {
    .Call(`_SelectSim_rcpp_overlap`, v, t)
}

rcpp_w_overlap <- function(v, w, t = 1L) {
    .Call(`_SelectSim_rcpp_w_overlap`, v, w, t)
}

###
# Author  : Arvind Iyer, Miljan Petrovic
# Project : SelectSim
# Desc    : The file contains plot related functions
# Version : 0.1.6
###

# Suppress R CMD check notes for ggplot2/ggridges column name variables
utils::globalVariables(c(
  "density", "fill", "freq", "group", "iscale",
  "name", "pairs", "scale", "x", "x_actual", "y", "ymin"
))


#' A clean ggplot2 theme for publication-quality plots
#'
#' @param base_size size of fonts
#' @param base_family type of font
#' @return A ggplot2 theme object.
#'
#' @examples
#' library(ggplot2)
#' ggplot(data.frame(x = 1:3, y = 1:3), aes(x, y)) +
#'   geom_point() + theme_Publication()
#'
#' @export
theme_Publication <- function(base_size = 14, base_family = "sans") {
  (theme(
    text = element_text(family = base_family, size = base_size),
    plot.title = element_text(face = "bold", size = rel(1.2), hjust = 0.5),
    panel.background = element_blank(),
    plot.background = element_blank(),
    panel.border = element_rect(colour = "black", fill = NA, linewidth = 1),
    axis.title = element_text(face = "bold", size = rel(1)),
    axis.title.y = element_text(angle = 90, vjust = 2),
    axis.title.x = element_text(vjust = -0.2),
    axis.text = element_text(size = rel(0.8)),
    axis.ticks = element_line(),
    panel.grid.major = element_line(colour = "#f0f0f0"),
    panel.grid.minor = element_blank(),
    legend.key = element_blank(),
    legend.position = "right",
    legend.text = element_text(size = rel(0.8)),
    legend.key.size = unit(4, "mm"),
    legend.direction = "vertical",
    legend.spacing = unit(0, "cm"),
    legend.title = element_text(face = "italic"),
    plot.margin = margin(5, 5, 5, 5, "mm"),
    strip.background = element_rect(colour = "black", fill = "white"),
    strip.text = element_text(face = "bold")
  ))
}


#' Scatter plot of observed vs expected weighted co-mutation
#'
#' Plots each gene pair as a point with observed weighted co-mutation on the y-axis
#' and expected (null model mean) on the x-axis. Significant co-mutations (CO) and
#' mutual exclusivities (ME) are coloured; non-significant pairs are grey.
#'
#' @import ggpubr
#' @import ggplot2
#' @importFrom  dplyr %>%
#' @importFrom  dplyr mutate
#' @importFrom  dplyr case_when
#' @param result Result table from \code{selectX()$result}.
#' @param title Plot title.
#' @return A ggplot2 object.
#'
#' @examples
#' \donttest{
#' data(luad_result, package = "SelectSim")
#' obs_exp_scatter(result = luad_result, title = "TCGA LUAD")
#' }
#'
#' @export

obs_exp_scatter <- function(result, title) {
  result$log_overlap <- log10(result$w_overlap + 1)
  result$log_r_overlap <- log10(result$w_r_overlap + 1)
  result <- result %>% mutate(cat = case_when(FDR == TRUE ~ type, FDR == FALSE ~ "NS"))

  plot <- ggscatter(result,
    x = "log_r_overlap",
    y = "log_overlap",
    color = "cat",
    palette = c("forestgreen", "purple", "grey93"),
    repel = TRUE,
    alpha = 1
  ) + xlab("Random weighted co-mutation (log10)") + ylab("Actual weighted co-mutation(log10)") + geom_abline(slope = 1, intercept = 0) +
    scale_y_continuous(breaks = seq(0, max(result$log_overlap), 1)) +
    scale_x_continuous(breaks = seq(0, max(result$log_overlap), 1))

  plot <- plot + ggtitle(title) + theme_Publication(base_size = 16) +
    theme(
      legend.position = "top",
      legend.title = element_blank()
    )

  return(plot)
}


#' Extract null-model weighted overlap distribution for a gene pair
#'
#' Returns the vector of weighted co-mutation values from all null-model
#' permutations for a specific pair of genes.
#'
#' @param gene1 Name of the first gene/alteration.
#' @param gene2 Name of the second gene/alteration.
#' @param obj SelectX object (list returned by \code{selectX()$obj}).
#' @return Numeric vector of length \code{obj$nSim} with the null-model
#'   weighted overlap values for the pair.
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' result <- selectX(M = luad_run_data$M,
#'                   sample.class = luad_run_data$sample.class,
#'                   alteration.class = luad_run_data$alteration.class,
#'                   n.cores = 1, min.freq = 10, n.permut = 10,
#'                   verbose = FALSE)
#' genes <- rownames(result$obj$al$am$full)[1:2]
#' overlap_pair_extract(genes[1], genes[2], result$obj)
#' }
#'
#' @export

overlap_pair_extract <- function(gene1, gene2, obj) {
  wes_dist <- c()
  panel_dist <- c()
  for (i in c(1:obj$nSim)) {
    rownames(obj$wrobs.co[[i]]) <- rownames(obj$al$am$full)
    colnames(obj$wrobs.co[[i]]) <- rownames(obj$al$am$full)
    wes_dist <- c(wes_dist, obj$wrobs.co[[i]][gene1, gene2])
  }
  return(wes_dist)
}


#' Ridge plot of null-model background distribution for significant gene pairs
#'
#' For each significant evolutionary dependency in \code{result_df}, plots the
#' null-model weighted-overlap distribution as a ridge, with vertical lines
#' marking the observed overlap (red) and mean background (blue).
#'
#' @import ggpubr
#' @import ggplot2
#' @import ggridges
#' @importFrom  dplyr %>%
#' @importFrom  dplyr case_when
#' @importFrom  dplyr group_by
#' @importFrom  dplyr ungroup
#' @importFrom  dplyr mutate
#' @importFrom  dplyr row_number
#' @importFrom  dplyr filter
#' @importFrom  dplyr left_join
#' @importFrom  dplyr arrange
#' @importFrom  dplyr distinct
#' @importFrom  stats as.dist
#' @importFrom  stats density
#' @importFrom  stats ecdf
#' @importFrom  stats runif
#' @importFrom  stats setNames
#' @param result_df Subset of the result table from \code{selectX()$result} containing
#'   only the pairs you want to display (e.g., significant hits).
#' @param obj SelectX object (\code{selectX()$obj}).
#' @return A ggplot2 ridge-plot object.
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' result <- selectX(M = luad_run_data$M,
#'                   sample.class = luad_run_data$sample.class,
#'                   alteration.class = luad_run_data$alteration.class,
#'                   n.cores = 1, min.freq = 10, n.permut = 10,
#'                   verbose = FALSE)
#' sig_pairs <- head(result$result[result$result$FDR, ], 3)
#' if (nrow(sig_pairs) > 0) ridge_plot_ed(sig_pairs, result$obj)
#' }
#'
#' @export

ridge_plot_ed <- function(result_df, obj) {
  pair_mat <- matrix(0, nrow = nrow(result_df), ncol = obj$nSim)
  for (row in c(1:nrow(result_df))) {
    gene1 <- (result_df[row, "SFE_1"])
    gene2 <- (result_df[row, "SFE_2"])
    pair <- (result_df[row, "name"])
    pair_mat[row, ] <- overlap_pair_extract(gene1, gene2, obj)
  }
  pair_mat_plot <- t(pair_mat)
  colnames(pair_mat_plot) <- result_df$name
  df <- setNames(as.data.frame.table(pair_mat_plot, stringsAsFactors = FALSE), c("rows", "pairs", "freq"))
  p <- ggplot(df, aes(x = freq, y = pairs)) +
    xlab("Co-mutated samples") +
    geom_density_ridges_gradient(quantile_lines = FALSE, quantiles = 2, color = "black", fill = "lightgrey") +
    theme_ridges(grid = TRUE, center_axis_labels = TRUE) +
    scale_x_continuous(breaks = seq(0, max(df$freq), by = 2))

  q <- ggplot_build(p)$data[[1]]
  density_lines <- q %>%
    group_by(group) %>%
    dplyr::filter(density == max(density)) %>%
    ungroup()
  temp <- df %>%
    distinct(pairs) %>%
    mutate(number = row_number())
  density_lines_complete <- left_join(density_lines, temp, by = c("group" = "number"))
  density_lines_complete$x_actual <- result_df$w_overlap

  a <- ifelse(result_df$type == "ME", "purple", "forestgreen")
  plot <- ggplot(
    df,
    aes(
      x = freq,
      y = pairs
    )
  ) +
    xlab("Weighted overlap") +
    ylab("") +
    geom_density_ridges_gradient(quantile_lines = FALSE, quantiles = 2, color = "black", fill = "lightgrey") +
    theme_ridges(grid = TRUE, center_axis_labels = TRUE, font_size = 18) +
    scale_x_continuous(breaks = seq(0, max(df$freq), by = 5)) +
    geom_segment(data = density_lines_complete, aes(x = x_actual, xend = x_actual, y = ymin, yend = ymin + density * scale * iscale, color = "Actual overlap")) +
    geom_segment(data = density_lines_complete, aes(x = x, xend = x, y = ymin, yend = ymin + density * scale * iscale, color = "Mean Background overlap")) +
    scale_color_manual("Legend", values = c("red", "blue")) +
    theme(axis.text.y = element_text(colour = a))

  return(plot)
}

#' Ridge plot comparing null-model distributions for two datasets
#'
#' For each gene pair in \code{result_df}, overlays the null-model weighted-overlap
#' distributions from two separate \code{selectX} runs, allowing visual comparison
#' of evolutionary dependencies across cohorts or conditions.
#'
#' @import ggpubr
#' @import ggplot2
#' @import ggridges
#' @importFrom  dplyr %>%
#' @importFrom  dplyr case_when
#' @importFrom  dplyr group_by
#' @importFrom  dplyr ungroup
#' @importFrom  dplyr mutate
#' @importFrom  dplyr row_number
#' @importFrom  dplyr filter
#' @importFrom  dplyr left_join
#' @importFrom  dplyr arrange
#' @importFrom  stats as.dist
#' @importFrom  stats density
#' @importFrom  stats ecdf
#' @importFrom  stats runif
#' @importFrom  stats setNames
#' @param result_df A data frame of gene pairs to display, with columns
#'   \code{SFE_1}, \code{SFE_2}, \code{name}, \code{type}, \code{dataset1_w_overlap},
#'   and \code{dataset2_w_overlap}.
#' @param obj1 SelectX object for dataset 1 (\code{selectX()$obj}).
#' @param obj2 SelectX object for dataset 2 (\code{selectX()$obj}).
#' @param name1 Display label for dataset 1.
#' @param name2 Display label for dataset 2.
#' @return A ggplot2 ridge-plot object.
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' r1 <- selectX(M = luad_run_data$M,
#'               sample.class = luad_run_data$sample.class,
#'               alteration.class = luad_run_data$alteration.class,
#'               n.cores = 1, min.freq = 10, n.permut = 10, verbose = FALSE)
#' r2 <- selectX(M = luad_run_data$M,
#'               sample.class = luad_run_data$sample.class,
#'               alteration.class = luad_run_data$alteration.class,
#'               n.cores = 1, min.freq = 10, n.permut = 10, verbose = FALSE)
#' common <- head(r1$result, 3)
#' common$dataset1_w_overlap <- common$w_overlap
#' common$dataset2_w_overlap <- common$w_overlap
#' ridge_plot_ed_compare(common, r1$obj, r2$obj, "Run1", "Run2")
#' }
#'
#' @export

ridge_plot_ed_compare <- function(result_df, obj1, obj2, name1, name2) {
  pair_mat <- matrix(0, nrow = nrow(result_df), ncol = obj1$nSim)
  for (row in c(1:nrow(result_df))) {
    gene1 <- (result_df[row, "SFE_1"])
    gene2 <- (result_df[row, "SFE_2"])
    pair <- (result_df[row, "name"])
    pair_mat[row, ] <- overlap_pair_extract(gene1, gene2, obj1)
  }
  pair_mat_plot <- t(pair_mat)
  colnames(pair_mat_plot) <- result_df$name
  df1 <- setNames(as.data.frame.table(pair_mat_plot, stringsAsFactors = FALSE), c("rows", "pairs", "freq"))

  pair_mat <- matrix(0, nrow = nrow(result_df), ncol = obj2$nSim)
  for (row in c(1:nrow(result_df))) {
    gene1 <- (result_df[row, "SFE_1"])
    gene2 <- (result_df[row, "SFE_2"])
    pair <- (result_df[row, "name"])
    pair_mat[row, ] <- overlap_pair_extract(gene1, gene2, obj2)
  }
  pair_mat_plot <- t(pair_mat)
  colnames(pair_mat_plot) <- result_df$name
  df2 <- setNames(as.data.frame.table(pair_mat_plot, stringsAsFactors = FALSE), c("rows", "pairs", "freq"))

  df1$name <- rep(name1, nrow(df1))
  df2$name <- rep(name2, nrow(df2))

  df <- rbind(df1, df2)

  p <- ggplot(df, aes(x = freq, y = pairs, fill = name)) +
    xlab("Co-mutated samples") +
    geom_density_ridges_gradient(quantile_lines = FALSE, quantiles = 2, color = "black") +
    scale_fill_manual(values = c("#E69F00", "#56B4E9")) +
    theme_ridges(grid = TRUE, center_axis_labels = TRUE) +
    scale_x_continuous(breaks = seq(0, max(df$freq), by = 5))

  q <- ggplot_build(p)$data[[1]]
  density_lines <- q %>%
    group_by(fill, y) %>%
    dplyr::filter(density == max(density)) %>%
    arrange(fill) %>%
    ungroup()

  density_lines$pairs <- c(result_df$name, result_df$name)
  density_lines$x_actual <- c(result_df$dataset1_w_overlap, result_df$dataset2_w_overlap)
  density_lines$name <- c(rep(name2, nrow(result_df)), rep(name1, nrow(result_df)))
  a <- ifelse(result_df$type == "ME", "purple", "forestgreen")
  plot <- ggplot(df,
    aes(
      x = freq,
      y = pairs,
      fill = name
    ),
    alpha = 0.2
  ) +
    xlab("Weighted overlap") +
    ylab("") +
    geom_density_ridges_gradient(quantile_lines = FALSE, quantiles = 2) +
    theme_ridges(grid = TRUE, center_axis_labels = TRUE, font_size = 18) +
    scale_x_continuous(breaks = seq(0, max(df$freq), by = 5)) +
    geom_segment(data = density_lines, aes(x = x_actual, xend = x_actual, y = ymin, yend = ymin + density * scale * iscale, color = name, linetype = "Actual overlap")) +
    geom_segment(data = density_lines, aes(x = x, xend = x, y = ymin, yend = ymin + density * scale * iscale, color = name, linetype = "Mean Background overlap")) +
    scale_color_manual("Line Color", values = c("red", "blue")) +
    scale_linetype_manual("Linetype", values = c("Actual overlap" = 1, "Mean Background overlap" = 2)) +
    scale_fill_manual("Dataset", values = c("#E69F00", "#56B4E9")) +
    theme(axis.text.y = element_text(colour = a))

  return(plot)
}

###
# Author  : Arvind Iyer
# Project : SelectSim
# Desc    : The file which contains the function to generate the stats and table
# Version : 0.1.6
###

#' Initialize an Alteration Landscape Stats (ALS) container
#'
#' @param al The alteration landscape object (checked for NULL)
#' @return Empty ALS list object.
#'
#' @examples
#' new.ALS(list())
#'
#' @export
new.ALS <- function(al) {
  if (is.null(al)) stop("Input al is NULL")
  als <- list()
  class(als) <- "ALS"
  return(als)
}
#' Initialize an Alteration Matrix Stats (AMS) container
#'
#' @param am The alteration matrix (checked for NULL)
#' @return Empty AMS list object.
#'
#' @examples
#' new.AMS(matrix(0, 2, 2))
#'
#' @export
new.AMS <- function(am) {
  if (is.null(am)) stop("Input am is NULL")
  ams <- list()
  class(ams) <- "AMS"
  return(ams)
}
#' Compute summary statistics for a binary alteration matrix
#'
#' @param am Binary alteration matrix (features x samples)
#' @return AMS object with basic counts: n.samples, n.alterations, n.occurrences, per-sample and per-feature counts.
#'
#' @examples
#' am <- matrix(c(0,1,1,0,1,1), nrow = 2,
#'              dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
#' am.stats(am)
#'
#' @export
am.stats <- function(am) {
  ams <- new.AMS(am)
  am <- am * 1.0
  sample.alt.n <- colSums(am, na.rm = TRUE)
  feat.alt.n <- rowSums(am, na.rm = TRUE)
  numOfEdges <- sum(abs(am), na.rm = TRUE)
  temp <- list(
    "n.samples" = ncol(am),
    "n.alterations" = nrow(am),
    "n.occurrences" = numOfEdges,
    "alterations.per.sample" = sample.alt.n,
    "alteration.count" = feat.alt.n
  )
  ams[names(temp)] <- temp
  return(ams)
}
#' Compute alteration landscape statistics
#'
#' @param al SelectX object (list containing al, W, etc. as returned by selectX)
#' @return ALS object with overall and per-block alteration statistics.
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' result <- selectX(M = luad_run_data$M,
#'                   sample.class = luad_run_data$sample.class,
#'                   alteration.class = luad_run_data$alteration.class,
#'                   n.cores = 1, min.freq = 10, n.permut = 10,
#'                   verbose = FALSE)
#' stats <- al.stats(result$obj)
#' }
#'
#' @export
al.stats <- function(al) {
  als <- new.ALS(al)
  temp <- am.stats(al$al$am$full)
  ams <- temp
  als[names(ams)] <- ams
  # get stats for each single block
  blocks <- get.blocks(al$al)
  als$sample.blocks <- list()
  for (ib in 1:length(blocks$sample.blocks)) {
    fib <- blocks$sample.blocks[[ib]]
    if (length(fib) > 0) {
      subM <- al$al$am$full[, fib, drop = FALSE]
      temp <- am.stats(subM)
      als$sample.blocks[[ib]] <- temp
    }
  }
  names(als$sample.blocks) <- names(blocks$sample.blocks)
  als$alteration.blocks <- list()
  for (ib in 1:length(blocks$alteration.blocks)) {
    fib <- blocks$alteration.blocks[[ib]]
    if (length(fib) > 0) {
      subM <- al$al$am$full[fib, , drop = FALSE]
      temp <- am.stats(subM)
      als$alteration.blocks[[ib]] <- temp
    }
  }
  names(als$alteration.blocks) <- names(blocks$alteration.blocks)

  return(als)
}

###
#' Compute pairwise alteration co-occurrence counts
#'
#' @importFrom  Matrix sparseMatrix
#' @importFrom  Matrix t
#' @param am Binary alteration matrix (features x samples)
#' @return Square matrix of pairwise co-occurrence counts (features x features).
#'
#' @examples
#' am <- matrix(c(0,1,1,0,1,1), nrow = 2,
#'              dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
#' am.pairwise.alteration.overlap(am)
#'
#' @export
am.pairwise.alteration.overlap <- function(am) {
  A <- am * 1
  overlap <- A %*% t(A)
  return(overlap)
}
#' Compute TMB-weighted pairwise alteration overlap
#'
#' @importFrom  Matrix sparseMatrix
#' @importFrom  Matrix t
#' @param am Binary alteration matrix (features x samples)
#' @param W Weight matrix (features x samples) with per-sample TMB weights
#' @return Weighted pairwise overlap matrix (features x features).
#'
#' @examples
#' am <- matrix(c(0,1,1,0,1,1), nrow = 2,
#'              dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
#' W  <- matrix(1, nrow = 2, ncol = 3,
#'              dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
#' am.weight.pairwise.alteration.overlap(am, W)
#'
#' @export
am.weight.pairwise.alteration.overlap <- function(am, W) {
  A <- am * 1
  col_order <- colnames(A)
  overlap <- (W[, col_order] * A) %*% t(A)
  return(overlap)
}
#' Compute pairwise alteration coverage statistics
#'
#' @importFrom  Matrix Matrix
#' @param overlap_M The pairwise overlap matrix
#' @param M.stats The alteration matrix stats (from am.stats)
#' @param w_overlap_M The weighted pairwise overlap matrix
#' @return List with overlap and w_overlap sparse matrices.
#'
#' @examples
#' am <- matrix(c(0,1,1,0,1,1), nrow = 2,
#'              dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
#' W  <- matrix(1, nrow = 2, ncol = 3,
#'              dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
#' ovlp  <- am.pairwise.alteration.overlap(am)
#' wovlp <- am.weight.pairwise.alteration.overlap(am, W)
#' stats <- am.stats(am)
#' am.pairwise.alteration.coverage(ovlp, stats, wovlp)
#'
#' @export
am.pairwise.alteration.coverage <- function(overlap_M, M.stats, w_overlap_M) {
  stats <- list()
  overlap_M <- as.matrix(overlap_M)
  w_overlap_M <- as.matrix(w_overlap_M)
  marginal_f1 <- replicate(ncol(overlap_M), M.stats$alteration.count[rownames(overlap_M)])
  colnames(marginal_f1) <- rownames(marginal_f1)
  marginal_f2 <- t(marginal_f1)
  diag(overlap_M) <- diag(marginal_f1)
  stats[["overlap"]] <- Matrix(overlap_M)
  stats[["w_overlap"]] <- Matrix(w_overlap_M)
  return(stats)
}
#' Compute pairwise alteration statistics for an alteration landscape
#'
#' @param al SelectX object (list containing al, W, etc.)
#' @param als Alteration landscape stats (from al.stats); computed internally if NULL
#' @param do.blocks Whether to also compute block-level pairwise stats
#' @return List with overlap and w_overlap matrices, plus optional sample.blocks entries.
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' result <- selectX(M = luad_run_data$M,
#'                   sample.class = luad_run_data$sample.class,
#'                   alteration.class = luad_run_data$alteration.class,
#'                   n.cores = 1, min.freq = 10, n.permut = 10,
#'                   verbose = FALSE)
#' al.pairwise.alteration.stats(result$obj)
#' }
#'
#' @export
al.pairwise.alteration.stats <- function(al, als = NULL, do.blocks = FALSE) {
  if (is.null(als)) als <- al.stats(al)
  M.overlap <- am.pairwise.alteration.overlap(as.matrix(al$al$am$full))
  M.woverlap <- am.weight.pairwise.alteration.overlap(al$al$am$full, al$W$W[, colnames(al$al$am$full)])
  M.pairwise <- am.pairwise.alteration.coverage(M.overlap, als, M.woverlap)

  if (do.blocks) {
    blocks <- get.blocks(al$al)
    pairwise.blocks <- list()
    for (ib in 1:length(blocks$sample.blocks)) {
      fib <- blocks$sample.blocks[[ib]]
      if (length(fib) > 0) {
        subM <- al$al$am$full[, fib, drop = FALSE]
        subW <- al$W$W[, fib, drop = FALSE]
        M.overlap.block <- am.pairwise.alteration.overlap(subM)
        M.woverlap.block <- am.weight.pairwise.alteration.overlap(subM[, order(fib)], subW[, order(fib)])
        M.pairwise.block <- am.pairwise.alteration.coverage(M.overlap.block, als$sample.blocks[[ib]], M.woverlap.block)
        pairwise.blocks[[ib]] <- M.pairwise.block
      }
    }
    names(pairwise.blocks) <- names(blocks$sample.blocks)
    M.pairwise[["sample.blocks"]] <- pairwise.blocks
  }
  return(M.pairwise)
}
#' Compute null overlap matrix
#'
#' @param null The null model (list of simulated binary matrices)
#' @param n.permut Accepted for API compatibility; currently unused internally.
#' @param n.cores Accepted for API compatibility; currently unused internally.
#' @return Overlap matrix summed across all permutations.
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' result <- selectX(M = luad_run_data$M,
#'                   sample.class = luad_run_data$sample.class,
#'                   alteration.class = luad_run_data$alteration.class,
#'                   n.cores = 1, min.freq = 10, n.permut = 10,
#'                   verbose = FALSE)
#' r.am.pairwise.alteration.overlap(result$obj$null, n.permut = result$obj$nSim)
#' }
#'
#' @export
r.am.pairwise.alteration.overlap <- function(null, n.permut, n.cores = 1) {
  return(rcpp_overlap(v = null, t = 1))
}
#' Compute null weighted overlap matrix
#'
#' @param null The null model (list of simulated binary matrices)
#' @param W The weight matrix (features x samples)
#' @param n.permut Accepted for API compatibility; currently unused internally.
#' @param n.cores Accepted for API compatibility; currently unused internally.
#' @return Weighted overlap matrix summed across all permutations.
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' result <- selectX(M = luad_run_data$M,
#'                   sample.class = luad_run_data$sample.class,
#'                   alteration.class = luad_run_data$alteration.class,
#'                   n.cores = 1, min.freq = 10, n.permut = 10,
#'                   verbose = FALSE)
#' w.r.am.pairwise.alteration.overlap(result$obj$null, W = result$obj$W$W,
#'                                    n.permut = result$obj$nSim)
#' }
#'
#' @export
w.r.am.pairwise.alteration.overlap <- function(null, W, n.permut, n.cores = 1) {
  return(rcpp_w_overlap(v = null, w = W, t = 1))
}
#' Sum a list of matrices element-wise
#'
#' @param x List of matrices of identical dimensions
#' @return Single matrix that is the element-wise sum of all matrices in x
#'
#' @examples
#' mats <- list(matrix(1:4, 2, 2), matrix(1:4, 2, 2))
#' add(mats)
#'
#' @export
add <- function(x) Reduce("+", x)
#' Compute effect size between observed and expected overlap
#'
#' @param obs The observed overlap values
#' @param exp The expected (null model mean) overlap values
#' @return Effect size value(s)
#'
#' @examples
#' effectSize(obs = 5, exp = 3)
#' effectSize(obs = c(5, 2, 0), exp = c(3, 3, 1))
#'
#' @export
effectSize <- function(obs, exp) {
  es <- (obs - exp) * sin(pi / 4)
  return(es)
}
#' Compute effect sizes for null model permutations
#'
#' @param null_overlap List of null model overlap matrices (one per permutation)
#' @param mean_mat Mean overlap matrix across all permutations
#' @param n.permut Number of permutations
#' @param n.cores Number of cores (currently unused; sequential only)
#' @return List of effect size vectors, one per permutation.
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' result  <- selectX(M = luad_run_data$M,
#'                    sample.class = luad_run_data$sample.class,
#'                    alteration.class = luad_run_data$alteration.class,
#'                    n.cores = 1, min.freq = 10, n.permut = 10,
#'                    verbose = FALSE)
#' null_ov  <- r.am.pairwise.alteration.overlap(result$obj$null,
#'                                              n.permut = result$obj$nSim)
#' mean_mat <- Reduce("+", null_ov) / result$obj$nSim
#' r.effectSize(null_ov, mean_mat, n.permut = result$obj$nSim)
#' }
#'
#' @export
r.effectSize <- function(null_overlap, mean_mat, n.permut = 1000, n.cores = 1) {
  foreach::registerDoSEQ()
  i <- NULL
  r.effect <- foreach(i = 1:n.permut) %do% as.vector(as.dist((null_overlap[[i]] - mean_mat) * sin(pi / 4)))
  return(r.effect)
}
#' Compute Yule Q coefficient for all gene pairs
#'
#' @param overlap The pairwise overlap matrix
#' @param mat The binary GAM (features x samples)
#' @return Matrix of Yule Q coefficients
#'
#' @examples
#' am   <- matrix(c(0,1,1,0,1,1), nrow = 2,
#'                dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
#' ovlp <- am.pairwise.alteration.overlap(am)
#' binary.yule(ovlp, am)
#'
#' @export
binary.yule <- function(overlap, mat) {
  overlap <- as.matrix(overlap)
  marginal_f1 <- replicate(ncol(overlap), diag(overlap))
  colnames(marginal_f1) <- rownames(marginal_f1)
  marginal_f2 <- t(marginal_f1)
  v_11 <- overlap
  v_10 <- marginal_f1 - v_11
  v_01 <- marginal_f2 - v_11
  v_00 <- ncol(mat) - v_11 - v_01 - v_10

  # Calculate Odds Ratio
  OR <- (v_00 * v_11) / (v_10 * v_01)
  Yule <- (sqrt(OR) - 1) / (sqrt(OR) + 1)
  return(Yule)
}

#' Estimate FDR by scanning observed vs null effect sizes
#'
#' @param obs Vector of observed effect sizes
#' @param exp Vector of null model effect sizes (all permutations concatenated)
#' @param nSim Number of permutations used to generate exp
#' @param maxFDR FDR cutoff; scanning stops once FDR exceeds this value
#' @return Vector of FDR values, one per element of obs.
#'
#' @examples
#' set.seed(1)
#' obs <- c(0.8, 0.5, 0.3, 0.1)
#' exp <- runif(400)
#' estimateFDR2(obs, exp, nSim = 100)
#'
#' @export
estimateFDR2 <- function(obs, exp, nSim, maxFDR = 0.25) {
  all.fdr <- rep(1, length(obs))
  orig.obs <- obs
  obs <- sort(obs, decreasing = TRUE)
  exp <- sort(exp, decreasing = TRUE)
  obs.pos <- 1
  exp.pos <- 1
  scan <- TRUE
  while (scan) {
    if (obs.pos > length(obs)) {
      scan <- FALSE
    } else {
      value <- obs[obs.pos]
      while (exp[exp.pos] >= value) {
        exp.pos <- exp.pos + 1
        if (exp.pos == length(exp)) {
          break
        }
      }
      fp <- (exp.pos - 1) / nSim
      fdr <- min(fp / sum(obs >= value), 1)
      all.fdr[orig.obs == value] <- fdr
      if (fdr >= maxFDR) {
        scan <- FALSE
      }
      obs.pos <- obs.pos + 1
    }
  }
  # print('------------')
  return(all.fdr)
}

#' Compute empirical two-sided p-value for a gene pair
#'
#' @param robs_co List of null model overlap matrices (one per permutation)
#' @param obs.co Observed pairwise overlap matrix
#' @param gene1 Name of the first gene/alteration
#' @param gene2 Name of the second gene/alteration
#' @return Two-sided empirical p-value
#'
#' @examples
#' set.seed(1)
#' genes <- c("geneA", "geneB")
#' robs_co <- lapply(seq_len(20), function(i) {
#'   m <- matrix(sample(0:5, 4, replace = TRUE), 2, 2,
#'               dimnames = list(genes, genes))
#'   m
#' })
#' obs_co <- matrix(c(5, 3, 3, 4), 2, 2, dimnames = list(genes, genes))
#' estimate_p_val(robs_co, obs_co, "geneA", "geneB")
#'
#' @export

estimate_p_val <- function(robs_co, obs.co, gene1, gene2) {
  background <- c()
  for (obj in robs_co) {
    background <- c(background, obj[c(gene1, gene2), c(gene1, gene2)][1, 2])
  }
  actual_ratio <- obs.co[c(gene1, gene2), c(gene1, gene2)][1, 2]
  P <- ecdf(unlist(background))
  p_val <- 2 * min(P(actual_ratio), 1 - P(actual_ratio))
  return(p_val)
}

#' Compute p-values for all gene pairs in a results table
#'
#' @param obs Observed pairwise overlap matrix
#' @param exp List of null model overlap matrices (one per permutation)
#' @param results Results data frame with SFE_1 and SFE_2 columns
#' @param nSim Number of permutations
#' @return Vector of p-values, one per row in results.
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' result <- selectX(M = luad_run_data$M,
#'                   sample.class = luad_run_data$sample.class,
#'                   alteration.class = luad_run_data$alteration.class,
#'                   n.cores = 1, min.freq = 10, n.permut = 10,
#'                   verbose = FALSE, estimate_pairwise = TRUE)
#' head(result$result[, c("SFE_1","SFE_2","pairwise_p")])
#' }
#'
#' @export
estimate_pairwise_p <- function(obs, exp, results, nSim) {
  robs_co <- list()
  k <- 1
  for (obj in exp) {
    robs_co[[k]] <- obj
    rownames(robs_co[[k]]) <- rownames(obs)
    colnames(robs_co[[k]]) <- rownames(obs)
    k <- k + 1
  }
  p_val <- c()
  for (row in rownames(results)) {
    gene1 <- results[row, "SFE_1"]
    gene2 <- results[row, "SFE_2"]
    p_val <- c(p_val, estimate_p_val(robs_co, obs, gene1, gene2))
  }
  return(p_val)
}


#' Build the full interaction results table from selectX outputs
#'
#' @param al Alteration landscape object (al$am, etc.)
#' @param als Alteration landscape stats (from al.stats)
#' @param obs Observed pairwise overlap matrix
#' @param wobs Weighted observed pairwise overlap matrix
#' @param r.obs List of null model overlap matrices
#' @param r.wobs List of null model weighted overlap matrices
#' @param null Null model list (simulated binary matrices)
#' @param maxFDR FDR cutoff for calling significant results
#' @param estimate_pairwise Whether to compute per-pair empirical p-values
#' @param n.cores Number of cores
#' @param n.permut Number of permutations
#' @return Data frame with one row per gene pair and columns for overlap, effect sizes, FDR, and interaction type.
#'
#' @examples
#' \donttest{
#' data(luad_run_data, package = "SelectSim")
#' result <- selectX(M = luad_run_data$M,
#'                   sample.class = luad_run_data$sample.class,
#'                   alteration.class = luad_run_data$alteration.class,
#'                   n.cores = 1, min.freq = 10, n.permut = 10,
#'                   verbose = FALSE)
#' head(result$result)
#' }
#'
#' @export
interaction.table <- function(al,
                              als,
                              obs,
                              wobs,
                              r.obs = NULL,
                              r.wobs = NULL,
                              null,
                              maxFDR = 0.2,
                              n.cores = 1,
                              estimate_pairwise = FALSE,
                              n.permut = 1000) {
  features <- rownames(al$am$full)
  num_features <- length(features)
  result_cols <- c("SFE_1", "SFE_2")
  results <- data.frame(matrix(NA, nrow = num_features * (num_features - 1) / 2, ncol = length(result_cols)))
  colnames(results) <- result_cols
  temp <- rep(1:length(features), length(features))
  dim(temp) <- c(length(features), length(features))
  diag(temp) <- NA
  temp1 <- t(temp)
  temp1[which(temp1 > temp)] <- NA
  temp[which(temp < temp1)] <- NA
  temp <- cbind(as.vector(temp1), as.vector(temp))
  temp <- temp[which(!is.na(temp[, 1]) & !is.na(temp[, 2])), , drop = FALSE]
  results[, "SFE_1"] <- features[temp[, 1]]
  results[, "SFE_2"] <- features[temp[, 2]]
  rownames(results) <- paste(results[, "SFE_1"], results[, "SFE_2"], sep = " - ")
  results[, "name"] <- rownames(results)
  results[, "support_1"] <- als$alteration.count[results[, "SFE_1"]]
  results[, "support_2"] <- als$alteration.count[results[, "SFE_2"]]
  results[, "freq_1"] <- results[, "support_1"] / als$n.samples
  results[, "freq_2"] <- results[, "support_2"] / als$n.samples
  results[, "overlap"] <- as.vector(as.dist(obs))
  results[, "w_overlap"] <- as.vector(as.dist(wobs))
  # Get max possible overlap
  if (!is.null(als$sample.blocks)) {
    A <- lapply(als$sample.blocks, function(x) {
      a <- rep(x$alteration.count, length(x$alteration.count))
      dim(a) <- c(length(x$alteration.count), length(x$alteration.count))
      rownames(a) <- names(x$alteration.count)
      colnames(a) <- names(x$alteration.count)
      b <- t(a)
      c <- pmin(a, b)
    })
    A <- Reduce("+", A)
    results$max_overlap <- as.vector(as.dist(A))
  }
  results[, "freq_overlap"] <- results[, "overlap"] / (results[, "max_overlap"])
  results[, "r_overlap"] <- as.vector(as.dist(add(r.obs) / length(r.obs)))
  results[, "w_r_overlap"] <- as.vector(as.dist(add(r.wobs) / length(r.wobs)))
  if (estimate_pairwise) {
    obs.co <- as.matrix(als$alteration.pairwise$overlap)
    results[, "pairwise_p"] <- rep(1, nrow(results))
    results[, "pairwise_p"] <- estimate_pairwise_p(
      obs = obs.co,
      exp = r.obs,
      results = results,
      nSim = n.permut
    )
  }
  exp.ES <- (results[, "w_overlap"] - results[, "w_r_overlap"]) * sin(pi / 4)
  exp.ES <- as.numeric(exp.ES)
  results[, "wES"] <- exp.ES
  exp.rES <- r.effectSize(r.wobs, (add(r.wobs) / length(r.wobs)), n.permut = n.permut, n.cores = n.cores)
  exp.ES <- unlist(exp.rES)
  exp.ES <- as.numeric(exp.ES)
  results[, "wFDR"] <- rep(1, nrow(results))
  results[, "wFDR"] <- estimateFDR2(
    obs = abs(results[, "wES"]),
    exp = abs(exp.ES),
    maxFDR = maxFDR,
    nSim = n.permut
  )
  ES_mtx <- matrix(abs(unlist(exp.rES)), ncol = length(exp.rES), nrow = length(exp.rES[[1]]))
  mean_ES <- abs(rowSums(ES_mtx) / n.permut)
  n.ES <- (abs(results[, "wES"]) - abs(mean_ES))
  n.ES[n.ES < 0] <- 0
  results[, "nES"] <- sign(results[, "wES"]) * n.ES
  results[, "mean_r_nES"] <- sign(results[, "wES"]) * abs(mean_ES)
  exp.rES <- (abs(ES_mtx) - abs(mean_ES))
  exp.rES[exp.rES < 0] <- 0
  exp.rES <- sign(ES_mtx) * exp.rES
  exp.ES <- unlist(exp.rES)
  exp.ES <- as.numeric(exp.ES)
  results[, "nFDR"] <- rep(1, nrow(results))
  results[, "nFDR"] <- estimateFDR2(
    obs = abs(results[, "nES"]),
    exp = abs(exp.ES),
    maxFDR = maxFDR,
    nSim = n.permut
  )
  results[, "cum_freq"] <- results$support_1 + results$support_2
  samples <- length(colnames(al$am$full))
  freq.cats <- c(0, 0.02, 0.05, 0.10, 1)
  results$nFDR2 <- rep(1, nrow(results))
  for (i in 2:length(freq.cats)) {
    select <- results[, "cum_freq"] > freq.cats[i - 1] * 2 * samples & results[, "cum_freq"] < freq.cats[i] * 2 * samples
    if (sum(select) > 1) {
      results$nFDR2[select] <- estimateFDR2(
        obs = abs(results$nES[select]),
        exp = abs(as.numeric(unlist(exp.rES[select, ]))),
        maxFDR = maxFDR,
        nSim = n.permut
      )
    }
  }
  results <- results[order(abs(results$nES), decreasing = TRUE), ]
  results$type <- rep("ME", nrow(results))
  results$type[results$nES > 0] <- "CO"
  results$FDR <- results$nFDR2 <= maxFDR
  return(results)
}

###
# Author  : Marco Mina , Arvind Iyer
# Project : SelectSim
# Desc    : Functions to process the maf to gam
# Version : 0.1.6
###


## General Schemas

###
#' Mutation list object
#'
#' @export
#' @return A list containing the supported mutation-type classifications.
#' @examples
#' str(mutation_type)
mutation_type <- list(
  "truncating" = c("Nonsense_Mutation", "Frame_Shift_Ins", "Frame_Shift_Del", "Splice_Site", "In_Frame_Ins", "In_Frame_Del"),
  "missense" = c("Missense_Mutation", "Splice_Site"),
  "ignore" = c("Silent", "lincRNA", "IGR", "3'UTR", "5'UTR", "Intron", "5'Flank", "3'Flank", "RNA", "synonymous_variant", "upstream_gene_variant", "intron_variant", "3_prime_UTR_variant", "5_prime_UTR_variant", "downstream_gene_variant", "5_prime_UTR_premature_start_codon_gain_variant")
)

###
#' TCGA_maf_schema: schema for TCGA maf file to process the mutations
#'
#' @export
#' @return A list defining the expected TCGA MAF column schema.
#' @examples
#' str(TCGA_maf_schema)
TCGA_maf_schema <- list(
  "name" = "TCGA_maf",
  "column" = list(
    "gene" = "Hugo_Symbol",
    "gene.name" = "Hugo_Symbol",
    "sample" = "Tumor_Sample_Barcode",
    "sample.name" = "Tumor_Sample_Barcode",
    "mutation.type" = "Variant_Classification",
    "mutation" = "HGVSp_Short"
  ),
  "mutation.type" = list(
    "truncating" = unique(c(mutation_type$truncating, "Nonsense_Mutation", "Frame_Shift_Ins", "Frame_Shift_Del", "Splice_Site")),
    "missense" = unique(c(mutation_type$missense, "Missense_Mutation", "Splice_Site", "In_Frame_Ins", "In_Frame_Del")),
    "ignore" = unique(c(mutation_type$ignore))
  )
)

###
#' GENIE_maf_schema: schema for GENIE maf file to process the mutations
#'
#' @export
#' @return A list defining the expected GENIE MAF column schema.
#' @examples
#' str(GENIE_maf_schema)
GENIE_maf_schema <- list(
  "column" = list(
    "gene" = "Hugo_Symbol",
    "gene.name" = "Hugo_Symbol",
    "sample" = "Tumor_Sample_Barcode",
    "sample.name" = "Tumor_Sample_Barcode",
    "mutation.type" = "Variant_Classification",
    "mutation" = "HGVSp_Short"
  ),
  "mutation.type" = list(
    "truncating" = unique(c("Nonsense_Mutation", "Frame_Shift_Ins", "Frame_Shift_Del", "Splice_Site", "In_Frame_Ins", "In_Frame_Del")),
    "missense" = unique(c("Missense_Mutation", "Splice_Site")),
    "ignore" = unique(c(mutation_type$ignore))
  )
)


###
#' Filter maf function
#'
#' @description
#' `filter_maf_column()` takes a maf file and filters a MAF dataframe by retaining only the rows with a column value included in the values list
#'
#' @param maf a maf as dataframe
#' @param values a list containing the elements to filter
#' @param column column in maf file to filter
#' @param inclusive a boolean to include or exclude the data frame with values in list provided
#' @param fixed a grep argument to specify if grep use the argument as string or not
#' @param ... Other options
#' @return filtered_maf  a filtered maf file
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' filter_maf_column(luad_maf, values = "Missense_Mutation",
#'                   column = "Variant_Classification")
#'
#' @export
filter_maf_column <- function(maf, # the maf as dataframe
                              values, # values as list to filter
                              column, # column in the maf file to filter from
                              inclusive = TRUE, # Boolean to decide to include the values provided or not
                              fixed = TRUE, # grep argument to mention if it a regex or string
                              ...) {
  if (!column %in% colnames(maf)) stop(paste(column, "is not a valid column for the specified maf"))
  filtered_maf <- maf

  if (fixed) {
    if (inclusive) filtered_maf <- filtered_maf[which(filtered_maf[, column] %in% values), , drop = FALSE]
    if (!inclusive) filtered_maf <- filtered_maf[which(!filtered_maf[, column] %in% values), , drop = FALSE]
  } else {
    if ((length(unique(values)) * nrow(filtered_maf)) > 100000) warning(paste("Running grep on", length(unique(values)), "unique values vs", nrow(filtered_maf), "maf rows..."))
    if (inclusive) {
      temp <- lapply(unique(values), function(x) {
        filtered_maf[grep(x, filtered_maf[, column], fixed = !fixed), , drop = FALSE]
      })
    }
    if (!inclusive) {
      temp <- lapply(unique(values), function(x) {
        filtered_maf[grep(x, filtered_maf[, column], invert = TRUE, fixed = !fixed), , drop = FALSE]
      })
    }
    temp <- temp[sapply(temp, nrow) > 0]
    filtered_maf <- do.call(rbind, temp)
  }
  filtered_maf <- unique(filtered_maf)
  return(filtered_maf)
}

#' Filter a MAF dataframe by a combination of column values
#'
#' @param maf A MAF dataframe
#' @param values A dataframe of (column, value) pairs to match against
#' @param ... Additional arguments passed to merge
#' @return Filtered MAF dataframe containing only rows matching the value combinations.
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' combos <- data.frame(Hugo_Symbol = "TP53",
#'                      Variant_Classification = "Missense_Mutation")
#' filter_maf_complex(luad_maf, combos,
#'                    by.x = c("Hugo_Symbol","Variant_Classification"),
#'                    by.y = c("Hugo_Symbol","Variant_Classification"))
#'
#' @export
filter_maf_complex <- function(maf, values, ...) {
  filtered_maf <- merge(maf, values, suffixes = c("", "_to.ignore"), ...)
  filtered_maf <- unique(filtered_maf)
  return(filtered_maf)
}

#' Filter a MAF dataframe by sample ID
#'
#' @param maf A MAF dataframe
#' @param samples Vector of sample IDs to retain
#' @param sample.col Column name containing sample IDs
#' @param ... Additional arguments passed to filter_maf_column
#' @return Filtered MAF dataframe.
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' ids <- unique(luad_maf$Tumor_Sample_Barcode)[1:5]
#' filter_maf_sample(luad_maf, samples = ids)
#'
#' @export
filter_maf_sample <- function(maf, samples, sample.col = "Tumor_Sample_Barcode", ...) {
  filtered_maf <- filter_maf_column(maf, values = samples, column = sample.col, ...)
  return(filtered_maf)
}

#' Filter a MAF dataframe by gene name
#'
#' @param maf A MAF dataframe
#' @param genes Vector of gene names to retain
#' @param gene.col Column name containing gene symbols
#' @param ... Additional arguments passed to filter_maf_column
#' @return Filtered MAF dataframe.
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' filter_maf_gene.name(luad_maf, genes = c("TP53", "KRAS"))
#'
#' @export
filter_maf_gene.name <- function(maf, genes, gene.col = "Hugo_Symbol", ...) {
  filtered_maf <- filter_maf_column(maf, values = genes, column = gene.col, ...)
  return(filtered_maf)
}

#' Filter a MAF dataframe by mutation type
#'
#' @param maf A MAF dataframe
#' @param variants Vector of variant classification values to retain
#' @param variant.col Column name containing variant classifications
#' @param ... Additional arguments passed to filter_maf_column
#' @return Filtered MAF dataframe.
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' filter_maf_mutation.type(luad_maf, variants = "Missense_Mutation")
#'
#' @export
filter_maf_mutation.type <- function(maf, variants, variant.col = "Variant_Classification", ...) {
  filtered_maf <- filter_maf_column(maf, values = variants, column = variant.col, ...)
  return(filtered_maf)
}

#' Filter a MAF dataframe by specific gene-mutation combinations
#'
#' @param maf A MAF dataframe
#' @param values Dataframe of allowed (gene, mutation) combinations
#' @param maf.col Columns in maf to join on
#' @param values.col Corresponding columns in values to join on
#' @param ... Additional arguments passed to filter_maf_complex
#' @return Filtered MAF dataframe containing only rows matching the allowed combinations.
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' allowed <- data.frame(Hugo_Symbol  = c("TP53", "KRAS"),
#'                       HGVSp_Short  = c("p.R175H", "p.G12C"))
#' filter_maf_mutations(luad_maf, allowed)
#'
#' @export
filter_maf_mutations <- function(maf, values, maf.col = c("Hugo_Symbol", "HGVSp_Short"), values.col = maf.col, ...) {
  filtered_maf <- filter_maf_complex(maf, values = values, by.x = maf.col, by.y = values.col, ...)
  return(filtered_maf)
}


# Schema functions

###
#' This function filters a MAF dataframe by sample id
#'
#' @description
#' `filter_maf_schema()` takes a maf file and filters a MAF dataframe by retaining only the rows with a column value included in the values list
#'
#' @param maf a maf as dataframe
#' @param schema a data-frame schema; see `TCGA_maf_schema` for an example
#' @param column column in maf file to filter
#' @param values a list containing the elements to file
#' @param ... Other options
#' @return filtered_maf  a filtered maf file
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' filter_maf_schema(luad_maf, TCGA_maf_schema,
#'                   column = "mutation.type",
#'                   values = TCGA_maf_schema$mutation.type$truncating)
#'
#' @export
filter_maf_schema <- function(maf, schema = TCGA_maf_schema, column, values, ...) {
  variant.col <- schema[["column"]][[column]]
  filtered_maf <- filter_maf_column(maf, values = values, column = variant.col, ...)
  return(filtered_maf)
}


###
#' This function filters a MAF dataframe by retaining (or discarding) truncating mutations
#'
#' @description
#' `filter_maf_truncating()` takes a maf file and filters a MAF dataframe by retaining only the rows with a column value included in the values list
#'
#' @param maf a maf as dataframe
#' @param schema a data-frame schema; see `TCGA_maf_schema` for an example
#' @param ... Other options
#' @return filtered_maf  a filtered maf file
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' filter_maf_truncating(luad_maf)
#'
#' @export
filter_maf_truncating <- function(maf, schema = TCGA_maf_schema, ...) {
  column <- "mutation.type"
  filtered_maf <- filter_maf_schema(maf, schema = schema, column = column, values = schema[[column]][["truncating"]], ...)
  return(filtered_maf)
}


###
#' This function filters a MAF dataframe by retaining (or discarding) missense mutations
#'
#' @description
#' `filter_maf_missense()` takes a maf file and filters a MAF dataframe by retaining only the rows with a column value included in the values list
#'
#' @param maf a maf as dataframe
#' @param schema a data-frame schema; see `TCGA_maf_schema` for an example
#' @param ... Other options
#' @return filtered_maf  a filtered maf file
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' filter_maf_missense(luad_maf)
#'
#' @export
filter_maf_missense <- function(maf, schema = TCGA_maf_schema, ...) {
  column <- "mutation.type"
  filtered_maf <- filter_maf_schema(maf, schema = schema, column = column, values = schema[[column]][["missense"]], ...)
  return(filtered_maf)
}


###
#' This function filters a MAF dataframe by retaining (or discarding) ignore mutations
#'
#' @description
#' `filter_maf_ignore()` takes a maf file and filters a MAF dataframe by retaining only the rows with a column value included in the values list
#'
#' @param maf a maf as dataframe
#' @param schema a data-frame schema; see `TCGA_maf_schema` for an example
#' @param ... Other options
#' @return filtered_maf  a filtered maf file
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' filter_maf_ignore(luad_maf)
#'
#' @export
filter_maf_ignore <- function(maf, schema = TCGA_maf_schema, ...) {
  column <- "mutation.type"
  filtered_maf <- filter_maf_schema(maf, schema = schema, column = column, values = schema[[column]][["ignore"]], ...)
  return(filtered_maf)
}


## Summary functions

###
#' Summary functions for MAF file
#'
#' @description
#' `stat_maf_column()` takes a maf file and filters a MAF dataframe by retaining only the rows with a column value included in the values list
#'
#' @param maf a maf as dataframe
#' @param column a data-frame schema; see `TCGA_maf_schema` for an example
#' @param ... Other options
#' @return filtered_maf  a filtered maf file
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' stat_maf_column(luad_maf, column = "Variant_Classification")
#'
#' @export

stat_maf_column <- function(maf, column, ...) {
  if (!column %in% colnames(maf)) stop(paste(column, "is not a valid column for the specified maf"))
  v <- maf[, column]
  return(table(v))
}
###
#' Count mutations per sample in a MAF file
#'
#' @param maf A MAF dataframe
#' @param column Column name containing sample IDs
#' @param ... Additional arguments passed to stat_maf_column
#' @return Table of mutation counts per sample.
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' head(stat_maf_sample(luad_maf))
#'
#' @export
stat_maf_sample <- function(maf, column = "Tumor_Sample_Barcode", ...) {
  return(stat_maf_column(maf, column, ...))
}
###
#' Count mutations per gene in a MAF file
#'
#' @param maf A MAF dataframe
#' @param column Column name containing gene symbols
#' @param ... Additional arguments passed to stat_maf_column
#' @return Table of mutation counts per gene.
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' head(stat_maf_gene(luad_maf))
#'
#' @export
stat_maf_gene <- function(maf, column = "Hugo_Symbol", ...) {
  return(stat_maf_column(maf, column, ...))
}

## GAM generating function

###
#' Generate gam from the maf file
#'
#' @description
#' `maf2gam()` takes a maf file and converts into gam
#'
#' @param maf A MAF dataframe
#' @param sample.col Column name for sample IDs
#' @param gene.col Column name for gene symbols
#' @param value.var Column used as the value to aggregate
#' @param samples Vector of sample IDs to include; NULL keeps all samples present in the MAF
#' @param genes Vector of gene names to include; NULL keeps all genes present in the MAF
#' @param fun.aggregate Aggregation function applied per (sample, gene) cell
#' @param binarize If TRUE, convert aggregated counts to binary presence/absence
#' @param fill Value used for missing (sample, gene) combinations
#' @return Numeric matrix (samples x genes) representing the gene alteration matrix.
#'
#' @examples
#' data(luad_maf, package = "SelectSim")
#' small_maf <- luad_maf[
#'   luad_maf$Tumor_Sample_Barcode %in%
#'     unique(luad_maf$Tumor_Sample_Barcode)[1:5],
#' ]
#' gam <- maf2gam(small_maf)
#' dim(gam)
#'
#' @export
maf2gam <- function(maf,
                    sample.col = "Tumor_Sample_Barcode",
                    gene.col = "Hugo_Symbol",
                    value.var = "HGVSp_Short",
                    samples = NULL,
                    genes = NULL,
                    fun.aggregate = length,
                    binarize = TRUE,
                    fill = NA) {
  mut_gam <- tapply(maf[[value.var]], list(maf[[sample.col]], maf[[gene.col]]), FUN = fun.aggregate)
  if (binarize) {
    if (mode(mut_gam) == "character") {
      mut_gam <- mut_gam != ""
    } else if (mode(mut_gam) == "numeric") {
      mut_gam <- mut_gam > 0
    } else {
      mut_gam <- mut_gam > 0
    }
  }
  if (!is.null(samples)) {
    samples <- unique(samples)
    tokeep <- intersect(samples, rownames(mut_gam))
    mut_gam <- mut_gam[tokeep, , drop = FALSE]
    toadd <- samples[which(!samples %in% rownames(mut_gam))]
    voidadd <- matrix(fill, nrow = length(toadd), ncol = ncol(mut_gam))
    rownames(voidadd) <- toadd
    colnames(voidadd) <- colnames(mut_gam)
    mut_gam <- rbind(mut_gam, voidadd)
  }
  if (!is.null(genes)) {
    genes <- unique(genes)
    tokeep <- intersect(genes, colnames(mut_gam))
    mut_gam <- mut_gam[, tokeep, drop = FALSE]
    toadd <- genes[which(!genes %in% colnames(mut_gam))]
    voidadd <- matrix(fill, ncol = length(toadd), nrow = nrow(mut_gam))
    colnames(voidadd) <- toadd
    rownames(voidadd) <- rownames(mut_gam)
    mut_gam <- cbind(mut_gam, voidadd)
  }
  return(mut_gam)
}

test_that("maf2gam produces a binary matrix from luad_maf", {
  data(luad_maf, package = "SelectSim")
  gam <- maf2gam(luad_maf,
    sample.col = TCGA_maf_schema$column$sample,
    gene.col   = TCGA_maf_schema$column$gene
  )
  expect_true(is.matrix(gam))
  expect_true(nrow(gam) > 0)
  expect_true(ncol(gam) > 0)
  expect_true(all(gam %in% c(0L, 1L, TRUE, FALSE, NA)))
})

test_that("filter_maf_truncating retains only truncating variant types", {
  data(luad_maf, package = "SelectSim")
  filtered <- filter_maf_truncating(luad_maf, schema = TCGA_maf_schema)
  expect_true(nrow(filtered) > 0)
  expect_true(all(
    filtered[[TCGA_maf_schema$column$mutation.type]] %in%
      TCGA_maf_schema$mutation.type$truncating
  ))
})

test_that("filter_maf_missense retains only missense variant types", {
  data(luad_maf, package = "SelectSim")
  filtered <- filter_maf_missense(luad_maf, schema = TCGA_maf_schema)
  expect_true(nrow(filtered) > 0)
  expect_true(all(
    filtered[[TCGA_maf_schema$column$mutation.type]] %in%
      TCGA_maf_schema$mutation.type$missense
  ))
})

test_that("filter_maf_sample subsets to requested samples", {
  data(luad_maf, package = "SelectSim")
  sample_col <- TCGA_maf_schema$column$sample
  five_samples <- unique(luad_maf[[sample_col]])[seq_len(5)]
  filtered <- filter_maf_sample(luad_maf,
    samples = five_samples,
    sample.col = sample_col
  )
  expect_true(nrow(filtered) > 0)
  expect_true(all(filtered[[sample_col]] %in% five_samples))
})

test_that("stat_maf_sample returns counts summing to total mutations", {
  data(luad_maf, package = "SelectSim")
  counts <- stat_maf_sample(luad_maf, column = TCGA_maf_schema$column$sample)
  expect_equal(sum(counts), nrow(luad_maf))
})

test_that("stat_maf_gene returns a named table with all genes", {
  data(luad_maf, package = "SelectSim")
  counts <- stat_maf_gene(luad_maf, column = TCGA_maf_schema$column$gene)
  expect_true(is.table(counts))
  expected_genes <- unique(luad_maf[[TCGA_maf_schema$column$gene]])
  expect_true(all(expected_genes %in% names(counts)))
})

---
title: "Introduction to SelectSim"
author: "Arvind Iyer"
email: "arvind.iyer@unil.ch"
date: "`r Sys.Date()`"
output: 
 rmarkdown::html_vignette:
    css: doc.css
vignette: >
  %\VignetteIndexEntry{Introduction to SelectSim}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

SelectSim infers evolutionary dependencies — co-mutations and mutual exclusivities — between functional alterations across cancer genomes. It estimates expected co-mutation frequencies from individual gene mutation rates and per-sample tumor mutation burden (TMB), then evaluates significance against a permutation null model.

![SelectSim Method](SelectSim_method.png)

This package accompanies the manuscript: Iyer A, Mina M, Petrovic M, Ciriello G (2026). *Evolving patterns of co-mutations from tumor initiation to metastatic progression.* Nature Genetics.

### Installation

- You can install the development version of SelectSim from [GitHub](https://github.com/CSOgroup/SelectSim) with:

``` r
devtools::install_github("CSOgroup/SelectSim",dependencies = TRUE, build_vignettes = TRUE)
```

- For more details on installation refer to [INSTALLATION](https://github.com/CSOgroup/SelectSim/blob/main/INSTALLATION.md)

### Example

- We will run SelectSim algorithm on processed LUAD dataset from TCGA provided with the package.
- Note: This is an example for running a processed data. Check other vignette to process the data to create the run_data object needed as input for SelectSim algorithm.

```{r}
library(SelectSim)
library(dplyr)
## Load the data provided with the package
data(luad_run_data, package = "SelectSim")
```
#### Data Description & Format

- The loaded data is list object which consists of 
  - M: a list object of GAMs which is presence absence matrix of alterations
  - tmb: a list object of tumor mutation burden as data frame with column names (should be) as sample and mutation
  - sample.class a named vector of sample annotations
  - alteration.class a named vector of alteration annotations

```{r}
# Check the data structure
str(luad_run_data)
```

#### Running SelectSim
- We use the function `selectX()` which generates the background model and results.

| Parameter | Description |
|-----------|-------------|
| `M` | List of GAMs and TMB matrices |
| `sample.class` | Named vector of sample covariates |
| `alteration.class` | Named vector of alteration covariates |
| `min.freq` | Minimum number of samples a feature must be mutated in |
| `n.permut` | Number of permutations for the null model |
| `lambda` | Penalty factor for the weight computation |
| `tau` | Fold change threshold for the weight computation |
| `maxFDR` | FDR cutoff for calling significant results |

- The function returns a list object which contains the background model and results.

```{r}
result_obj<- SelectSim::selectX(  M = luad_run_data$M,
                      sample.class = luad_run_data$sample.class,
                      alteration.class = luad_run_data$alteration.class,
                      n.cores = 1,
                      min.freq = 10,
                      n.permut = 1000,
                      lambda = 0.3,
                      tau = 1,
                      save.object = FALSE,
                      verbose = FALSE,
                      estimate_pairwise = FALSE,
                      maxFDR = 0.25)
```

#### Interpreting the results
- Lets look into the results
```{r}
head(result_obj$result[,1:10],n=5)
```

##### Filtering significant hits
```{r}
# Filtering significant hits and counting EDs
result_obj$result %>% filter(nFDR2<=0.25) %>% head(n=2)
result_obj$result %>% filter(nFDR2<=0.25) %>% count(type)
```
##### Plotting a scatter plot of co-mutation
```{r}
# Filtering significant hits and plotting
obs_exp_scatter(result = result_obj$result,title = 'TCGA LUAD')
```


### Session information
```{r}
# Print the sessionInfo
sessionInfo()
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gam_utils.r
\name{filter_maf_ignore}
\alias{filter_maf_ignore}
\title{This function filters a MAF dataframe by retaining (or discarding) ignore mutations}
\usage{
filter_maf_ignore(maf, schema = TCGA_maf_schema, ...)
}
\arguments{
\item{maf}{a maf as dataframe}

\item{schema}{a data-frame schema; see \code{TCGA_maf_schema} for an example}

\item{...}{Other options}
}
\value{
filtered_maf  a filtered maf file
}
\description{
\code{filter_maf_ignore()} takes a maf file and filters a MAF dataframe by retaining only the rows with a column value included in the values list
}
\examples{
data(luad_maf, package = "SelectSim")
filter_maf_ignore(luad_maf)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_create.r
\name{generateS}
\alias{generateS}
\title{Generate S matrix}
\usage{
generateS(gam, sample.weights, upperBound = 1)
}
\arguments{
\item{gam}{the gam with genes*samples}

\item{sample.weights}{the samples weights}

\item{upperBound}{clip the values greater than 1 to keep it bounded between 0 to 1}
}
\value{
S the S matrix
}
\description{
Generate S matrix
}
\examples{
gam <- matrix(c(0,1,1,0,1,1), nrow = 2,
              dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
generateS(gam, sample.weights = c(s1 = 1, s2 = 1, s3 = 1))

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{am.weight.pairwise.alteration.overlap}
\alias{am.weight.pairwise.alteration.overlap}
\title{Compute TMB-weighted pairwise alteration overlap}
\usage{
am.weight.pairwise.alteration.overlap(am, W)
}
\arguments{
\item{am}{Binary alteration matrix (features x samples)}

\item{W}{Weight matrix (features x samples) with per-sample TMB weights}
}
\value{
Weighted pairwise overlap matrix (features x features).
}
\description{
Compute TMB-weighted pairwise alteration overlap
}
\examples{
am <- matrix(c(0,1,1,0,1,1), nrow = 2,
             dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
W  <- matrix(1, nrow = 2, ncol = 3,
             dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
am.weight.pairwise.alteration.overlap(am, W)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{effectSize}
\alias{effectSize}
\title{Compute effect size between observed and expected overlap}
\usage{
effectSize(obs, exp)
}
\arguments{
\item{obs}{The observed overlap values}

\item{exp}{The expected (null model mean) overlap values}
}
\value{
Effect size value(s)
}
\description{
Compute effect size between observed and expected overlap
}
\examples{
effectSize(obs = 5, exp = 3)
effectSize(obs = c(5, 2, 0), exp = c(3, 3, 1))

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gam_utils.r
\name{filter_maf_mutation.type}
\alias{filter_maf_mutation.type}
\title{Filter a MAF dataframe by mutation type}
\usage{
filter_maf_mutation.type(
  maf,
  variants,
  variant.col = "Variant_Classification",
  ...
)
}
\arguments{
\item{maf}{A MAF dataframe}

\item{variants}{Vector of variant classification values to retain}

\item{variant.col}{Column name containing variant classifications}

\item{...}{Additional arguments passed to filter_maf_column}
}
\value{
Filtered MAF dataframe.
}
\description{
Filter a MAF dataframe by mutation type
}
\examples{
data(luad_maf, package = "SelectSim")
filter_maf_mutation.type(luad_maf, variants = "Missense_Mutation")

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{interaction.table}
\alias{interaction.table}
\title{Build the full interaction results table from selectX outputs}
\usage{
interaction.table(
  al,
  als,
  obs,
  wobs,
  r.obs = NULL,
  r.wobs = NULL,
  null,
  maxFDR = 0.2,
  n.cores = 1,
  estimate_pairwise = FALSE,
  n.permut = 1000
)
}
\arguments{
\item{al}{Alteration landscape object (al$am, etc.)}

\item{als}{Alteration landscape stats (from al.stats)}

\item{obs}{Observed pairwise overlap matrix}

\item{wobs}{Weighted observed pairwise overlap matrix}

\item{r.obs}{List of null model overlap matrices}

\item{r.wobs}{List of null model weighted overlap matrices}

\item{null}{Null model list (simulated binary matrices)}

\item{maxFDR}{FDR cutoff for calling significant results}

\item{n.cores}{Number of cores}

\item{estimate_pairwise}{Whether to compute per-pair empirical p-values}

\item{n.permut}{Number of permutations}
}
\value{
Data frame with one row per gene pair and columns for overlap, effect sizes, FDR, and interaction type.
}
\description{
Build the full interaction results table from selectX outputs
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
result <- selectX(M = luad_run_data$M,
                  sample.class = luad_run_data$sample.class,
                  alteration.class = luad_run_data$alteration.class,
                  n.cores = 1, min.freq = 10, n.permut = 10,
                  verbose = FALSE)
head(result$result)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_create.r
\name{retrieveOutliers}
\alias{retrieveOutliers}
\title{Identify outlier null-model matrices}
\usage{
retrieveOutliers(obj, nSim = 1000)
}
\arguments{
\item{obj}{SelectX object (list with al and null fields)}

\item{nSim}{Number of simulations in the null model}
}
\value{
Logical vector; TRUE for each null matrix flagged as an outlier.
}
\description{
Flags simulations whose mean per-gene and per-sample deviation from the
observed counts falls in the top 10\%, indicating numerical instability.
These are removed before computing effect sizes to prevent them from
inflating the null distribution.
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
result <- selectX(M = luad_run_data$M,
                  sample.class = luad_run_data$sample.class,
                  alteration.class = luad_run_data$alteration.class,
                  n.cores = 1, min.freq = 10, n.permut = 10,
                  verbose = FALSE)
outliers <- retrieveOutliers(result$obj, nSim = result$obj$nSim)
sum(outliers)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gam_utils.r
\name{filter_maf_sample}
\alias{filter_maf_sample}
\title{Filter a MAF dataframe by sample ID}
\usage{
filter_maf_sample(maf, samples, sample.col = "Tumor_Sample_Barcode", ...)
}
\arguments{
\item{maf}{A MAF dataframe}

\item{samples}{Vector of sample IDs to retain}

\item{sample.col}{Column name containing sample IDs}

\item{...}{Additional arguments passed to filter_maf_column}
}
\value{
Filtered MAF dataframe.
}
\description{
Filter a MAF dataframe by sample ID
}
\examples{
data(luad_maf, package = "SelectSim")
ids <- unique(luad_maf$Tumor_Sample_Barcode)[1:5]
filter_maf_sample(luad_maf, samples = ids)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_create.r
\name{generateW_mean_tmb}
\alias{generateW_mean_tmb}
\title{Generate sample weight matrix from TMB values}
\usage{
generateW_mean_tmb(
  tmb,
  mean_tmb,
  ngenes,
  lambda = 0.3,
  tau = 1,
  discrete = TRUE
)
}
\arguments{
\item{tmb}{Numeric vector of per-sample TMB values.}

\item{mean_tmb}{Numeric scalar; the reference (expected) TMB used to compute
fold changes.}

\item{ngenes}{Integer; number of genes (rows) in the output weight matrix.}

\item{lambda}{Numeric; weight penalty factor. Higher values penalise
high-TMB samples more strongly (default 0.3).}

\item{tau}{Numeric; fold-change threshold below which no penalty is applied
(default 1).}

\item{discrete}{Logical; if \code{TRUE}, fold changes are rounded up before
applying the penalty (default \code{TRUE}).}
}
\value{
Numeric matrix of sample weights (ngenes x length(tmb)).
}
\description{
Computes a per-sample weight matrix based on the ratio of each sample's TMB to
the expected (mean) TMB. Samples with higher-than-expected TMB receive lower
weights via a penalty \code{lambda}, controlled by the fold-change threshold
\code{tau}.
}
\examples{
tmb      <- c(s1 = 10, s2 = 50, s3 = 20)
mean_tmb <- 25
generateW_mean_tmb(tmb, mean_tmb, ngenes = 3)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{luad_result}
\alias{luad_result}
\title{Lung adenocarcinoma from TCGA cohort as SelectSim run results}
\format{
A data frame
}
\usage{
data(luad_result)
}
\value{
A data frame containing SelectSim results for the LUAD cohort.
}
\description{
Result of LUAD generated by SelectSim with SelectSim run done at min.freq=10.
}
\examples{
data(luad_result)
dim(luad_result)
head(luad_result)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_plot.R
\name{ridge_plot_ed}
\alias{ridge_plot_ed}
\title{Ridge plot of null-model background distribution for significant gene pairs}
\usage{
ridge_plot_ed(result_df, obj)
}
\arguments{
\item{result_df}{Subset of the result table from \code{selectX()$result} containing
only the pairs you want to display (e.g., significant hits).}

\item{obj}{SelectX object (\code{selectX()$obj}).}
}
\value{
A ggplot2 ridge-plot object.
}
\description{
For each significant evolutionary dependency in \code{result_df}, plots the
null-model weighted-overlap distribution as a ridge, with vertical lines
marking the observed overlap (red) and mean background (blue).
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
result <- selectX(M = luad_run_data$M,
                  sample.class = luad_run_data$sample.class,
                  alteration.class = luad_run_data$alteration.class,
                  n.cores = 1, min.freq = 10, n.permut = 10,
                  verbose = FALSE)
sig_pairs <- head(result$result[result$result$FDR, ], 3)
if (nrow(sig_pairs) > 0) ridge_plot_ed(sig_pairs, result$obj)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_create.r
\name{new.AL.general}
\alias{new.AL.general}
\title{Create an Alteration Landscape (AL) object}
\usage{
new.AL.general(
  am,
  feat.covariates = NULL,
  sample.covariates = NULL,
  min.freq,
  verbose = FALSE
)
}
\arguments{
\item{am}{A named list with two required elements: \code{M} (a named list of binary
alteration matrices, each genes x samples) and \code{tmb} (a named list of data
frames, one per matrix in \code{M}, each with columns \code{sample} and
\code{mutation}). The names of \code{M} and \code{tmb} must match. All matrices
in \code{M} must have identical row and column names.}

\item{feat.covariates}{Named character vector of alteration-type annotations, one
entry per feature (gene). Names must match rownames of the matrices in \code{M}.
If \code{NULL}, all features are labelled \code{"MUT"}.}

\item{sample.covariates}{Named character vector of sample-type annotations, one
entry per sample. Names must match colnames of the matrices in \code{M}. If
\code{NULL}, all samples are labelled \code{"sample"}.}

\item{min.freq}{Minimum number of samples a gene must be mutated in (strictly
greater than) to be retained. Features with \code{rowSums <= min.freq} are
dropped.}

\item{verbose}{Logical; print progress messages.}
}
\value{
An Alteration Landscape (AL) object (list of class \code{"AL"}) containing
the filtered alteration matrices, TMB vectors, and covariate assignments.
}
\description{
Builds an Alteration Landscape object from a list of genome alteration matrices
and their corresponding tumor mutation burdens.
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
al <- new.AL.general(
  am               = luad_run_data$M,
  feat.covariates  = luad_run_data$alteration.class,
  sample.covariates = luad_run_data$sample.class,
  min.freq         = 10
)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{oncokb_genes}
\alias{oncokb_genes}
\title{OncoKB v3.9 cancer genes}
\format{
A list
}
\usage{
data(oncokb_genes)
}
\value{
An object containing cancer-associated genes annotated by OncoKB.
}
\description{
cancer genes list
}
\examples{
data(oncokb_genes)
length(oncokb_genes)
head(oncokb_genes)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_create.r
\name{template.obj.gen}
\alias{template.obj.gen}
\title{Generate the template matrix}
\usage{
template.obj.gen(al)
}
\arguments{
\item{al}{Alteration landscape object}
}
\value{
A list with \code{template.obj} (per-block S matrices) and
\code{temp_mat} (full concatenated template matrices, one per GAM type).
}
\description{
Computes the expected mutation probability matrices (one per GAM type, per
sample block) used as the simulation background in \code{null_model_parallel}.
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
al <- new.AL.general(luad_run_data$M,
                     feat.covariates  = luad_run_data$alteration.class,
                     sample.covariates = luad_run_data$sample.class,
                     min.freq = 10)
template.obj.gen(al)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gam_utils.r
\name{filter_maf_complex}
\alias{filter_maf_complex}
\title{Filter a MAF dataframe by a combination of column values}
\usage{
filter_maf_complex(maf, values, ...)
}
\arguments{
\item{maf}{A MAF dataframe}

\item{values}{A dataframe of (column, value) pairs to match against}

\item{...}{Additional arguments passed to merge}
}
\value{
Filtered MAF dataframe containing only rows matching the value combinations.
}
\description{
Filter a MAF dataframe by a combination of column values
}
\examples{
data(luad_maf, package = "SelectSim")
combos <- data.frame(Hugo_Symbol = "TP53",
                     Variant_Classification = "Missense_Mutation")
filter_maf_complex(luad_maf, combos,
                   by.x = c("Hugo_Symbol","Variant_Classification"),
                   by.y = c("Hugo_Symbol","Variant_Classification"))

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_run.R
\name{selectX}
\alias{selectX}
\title{SelectX main function from SelectSim to create alteration object with background model}
\usage{
selectX(
  M,
  sample.class,
  alteration.class,
  n.cores = 1,
  min.freq = 10,
  n.permut = 1000,
  lambda = 0.3,
  tau = 1,
  save.object = FALSE,
  folder = "./",
  verbose = TRUE,
  estimate_pairwise = FALSE,
  maxFDR = 0.25,
  seed = 42
)
}
\arguments{
\item{M}{a list data object which consist of gams and tmbs.}

\item{sample.class}{sample covariates as named list.}

\item{alteration.class}{alteration covariates as named list.}

\item{n.cores}{no of cores.}

\item{min.freq}{number of samples for features to be at least mutated in.}

\item{n.permut}{number of simulations.}

\item{lambda}{lambda parameter.}

\item{tau}{tau (fold change) parameter.}

\item{save.object}{store the SelectX object.}

\item{folder}{folder path to store the results.}

\item{verbose}{print the time and each steps.}

\item{estimate_pairwise}{Compute pairwise p-value}

\item{maxFDR}{FDR value}

\item{seed}{a random seed}
}
\value{
result  a SelectSim object with background model and other info along with result table
}
\description{
\code{selectX()} takes a list object which consist of genome alteration matrix and tumor mutation burden.
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
result <- selectX(
  M                = luad_run_data$M,
  sample.class     = luad_run_data$sample.class,
  alteration.class = luad_run_data$alteration.class,
  n.cores          = 1,
  min.freq         = 10,
  n.permut         = 10,
  verbose          = FALSE
)
head(result$result)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{estimate_p_val}
\alias{estimate_p_val}
\title{Compute empirical two-sided p-value for a gene pair}
\usage{
estimate_p_val(robs_co, obs.co, gene1, gene2)
}
\arguments{
\item{robs_co}{List of null model overlap matrices (one per permutation)}

\item{obs.co}{Observed pairwise overlap matrix}

\item{gene1}{Name of the first gene/alteration}

\item{gene2}{Name of the second gene/alteration}
}
\value{
Two-sided empirical p-value
}
\description{
Compute empirical two-sided p-value for a gene pair
}
\examples{
set.seed(1)
genes <- c("geneA", "geneB")
robs_co <- lapply(seq_len(20), function(i) {
  m <- matrix(sample(0:5, 4, replace = TRUE), 2, 2,
              dimnames = list(genes, genes))
  m
})
obs_co <- matrix(c(5, 3, 3, 4), 2, 2, dimnames = list(genes, genes))
estimate_p_val(robs_co, obs_co, "geneA", "geneB")

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_plot.R
\name{overlap_pair_extract}
\alias{overlap_pair_extract}
\title{Extract null-model weighted overlap distribution for a gene pair}
\usage{
overlap_pair_extract(gene1, gene2, obj)
}
\arguments{
\item{gene1}{Name of the first gene/alteration.}

\item{gene2}{Name of the second gene/alteration.}

\item{obj}{SelectX object (list returned by \code{selectX()$obj}).}
}
\value{
Numeric vector of length \code{obj$nSim} with the null-model
weighted overlap values for the pair.
}
\description{
Returns the vector of weighted co-mutation values from all null-model
permutations for a specific pair of genes.
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
result <- selectX(M = luad_run_data$M,
                  sample.class = luad_run_data$sample.class,
                  alteration.class = luad_run_data$alteration.class,
                  n.cores = 1, min.freq = 10, n.permut = 10,
                  verbose = FALSE)
genes <- rownames(result$obj$al$am$full)[1:2]
overlap_pair_extract(genes[1], genes[2], result$obj)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{binary.yule}
\alias{binary.yule}
\title{Compute Yule Q coefficient for all gene pairs}
\usage{
binary.yule(overlap, mat)
}
\arguments{
\item{overlap}{The pairwise overlap matrix}

\item{mat}{The binary GAM (features x samples)}
}
\value{
Matrix of Yule Q coefficients
}
\description{
Compute Yule Q coefficient for all gene pairs
}
\examples{
am   <- matrix(c(0,1,1,0,1,1), nrow = 2,
               dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
ovlp <- am.pairwise.alteration.overlap(am)
binary.yule(ovlp, am)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gam_utils.r
\name{stat_maf_gene}
\alias{stat_maf_gene}
\title{Count mutations per gene in a MAF file}
\usage{
stat_maf_gene(maf, column = "Hugo_Symbol", ...)
}
\arguments{
\item{maf}{A MAF dataframe}

\item{column}{Column name containing gene symbols}

\item{...}{Additional arguments passed to stat_maf_column}
}
\value{
Table of mutation counts per gene.
}
\description{
Count mutations per gene in a MAF file
}
\examples{
data(luad_maf, package = "SelectSim")
head(stat_maf_gene(luad_maf))

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{luad_maf}
\alias{luad_maf}
\title{Lung adenocarcinoma MAF from TCGA cohort}
\format{
A data frame
}
\usage{
data(luad_maf)
}
\value{
A data frame containing TCGA LUAD mutation data.
}
\description{
MAF file of LUAD from TCGA
}
\examples{
data(luad_maf)
dim(luad_maf)
head(luad_maf)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{new.ALS}
\alias{new.ALS}
\title{Initialize an Alteration Landscape Stats (ALS) container}
\usage{
new.ALS(al)
}
\arguments{
\item{al}{The alteration landscape object (checked for NULL)}
}
\value{
Empty ALS list object.
}
\description{
Initialize an Alteration Landscape Stats (ALS) container
}
\examples{
new.ALS(list())

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gam_utils.r
\name{filter_maf_column}
\alias{filter_maf_column}
\title{Filter maf function}
\usage{
filter_maf_column(maf, values, column, inclusive = TRUE, fixed = TRUE, ...)
}
\arguments{
\item{maf}{a maf as dataframe}

\item{values}{a list containing the elements to filter}

\item{column}{column in maf file to filter}

\item{inclusive}{a boolean to include or exclude the data frame with values in list provided}

\item{fixed}{a grep argument to specify if grep use the argument as string or not}

\item{...}{Other options}
}
\value{
filtered_maf  a filtered maf file
}
\description{
\code{filter_maf_column()} takes a maf file and filters a MAF dataframe by retaining only the rows with a column value included in the values list
}
\examples{
data(luad_maf, package = "SelectSim")
filter_maf_column(luad_maf, values = "Missense_Mutation",
                  column = "Variant_Classification")

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{al.pairwise.alteration.stats}
\alias{al.pairwise.alteration.stats}
\title{Compute pairwise alteration statistics for an alteration landscape}
\usage{
al.pairwise.alteration.stats(al, als = NULL, do.blocks = FALSE)
}
\arguments{
\item{al}{SelectX object (list containing al, W, etc.)}

\item{als}{Alteration landscape stats (from al.stats); computed internally if NULL}

\item{do.blocks}{Whether to also compute block-level pairwise stats}
}
\value{
List with overlap and w_overlap matrices, plus optional sample.blocks entries.
}
\description{
Compute pairwise alteration statistics for an alteration landscape
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
result <- selectX(M = luad_run_data$M,
                  sample.class = luad_run_data$sample.class,
                  alteration.class = luad_run_data$alteration.class,
                  n.cores = 1, min.freq = 10, n.permut = 10,
                  verbose = FALSE)
al.pairwise.alteration.stats(result$obj)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{al.stats}
\alias{al.stats}
\title{Compute alteration landscape statistics}
\usage{
al.stats(al)
}
\arguments{
\item{al}{SelectX object (list containing al, W, etc. as returned by selectX)}
}
\value{
ALS object with overall and per-block alteration statistics.
}
\description{
Compute alteration landscape statistics
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
result <- selectX(M = luad_run_data$M,
                  sample.class = luad_run_data$sample.class,
                  alteration.class = luad_run_data$alteration.class,
                  n.cores = 1, min.freq = 10, n.permut = 10,
                  verbose = FALSE)
stats <- al.stats(result$obj)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_plot.R
\name{obs_exp_scatter}
\alias{obs_exp_scatter}
\title{Scatter plot of observed vs expected weighted co-mutation}
\usage{
obs_exp_scatter(result, title)
}
\arguments{
\item{result}{Result table from \code{selectX()$result}.}

\item{title}{Plot title.}
}
\value{
A ggplot2 object.
}
\description{
Plots each gene pair as a point with observed weighted co-mutation on the y-axis
and expected (null model mean) on the x-axis. Significant co-mutations (CO) and
mutual exclusivities (ME) are coloured; non-significant pairs are grey.
}
\examples{
\donttest{
data(luad_result, package = "SelectSim")
obs_exp_scatter(result = luad_result, title = "TCGA LUAD")
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{am.stats}
\alias{am.stats}
\title{Compute summary statistics for a binary alteration matrix}
\usage{
am.stats(am)
}
\arguments{
\item{am}{Binary alteration matrix (features x samples)}
}
\value{
AMS object with basic counts: n.samples, n.alterations, n.occurrences, per-sample and per-feature counts.
}
\description{
Compute summary statistics for a binary alteration matrix
}
\examples{
am <- matrix(c(0,1,1,0,1,1), nrow = 2,
             dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
am.stats(am)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{estimateFDR2}
\alias{estimateFDR2}
\title{Estimate FDR by scanning observed vs null effect sizes}
\usage{
estimateFDR2(obs, exp, nSim, maxFDR = 0.25)
}
\arguments{
\item{obs}{Vector of observed effect sizes}

\item{exp}{Vector of null model effect sizes (all permutations concatenated)}

\item{nSim}{Number of permutations used to generate exp}

\item{maxFDR}{FDR cutoff; scanning stops once FDR exceeds this value}
}
\value{
Vector of FDR values, one per element of obs.
}
\description{
Estimate FDR by scanning observed vs null effect sizes
}
\examples{
set.seed(1)
obs <- c(0.8, 0.5, 0.3, 0.1)
exp <- runif(400)
estimateFDR2(obs, exp, nSim = 100)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_create.r
\name{get.blocks}
\alias{get.blocks}
\title{Get sample/alteration blocks}
\usage{
get.blocks(al)
}
\arguments{
\item{al}{The alteration landscape}
}
\value{
Classification of samples and alterations in blocks.
}
\description{
Get sample/alteration blocks
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
al <- new.AL.general(luad_run_data$M,
                     feat.covariates  = luad_run_data$alteration.class,
                     sample.covariates = luad_run_data$sample.class,
                     min.freq = 10)
get.blocks(al)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gam_utils.r
\name{maf2gam}
\alias{maf2gam}
\title{Generate gam from the maf file}
\usage{
maf2gam(
  maf,
  sample.col = "Tumor_Sample_Barcode",
  gene.col = "Hugo_Symbol",
  value.var = "HGVSp_Short",
  samples = NULL,
  genes = NULL,
  fun.aggregate = length,
  binarize = TRUE,
  fill = NA
)
}
\arguments{
\item{maf}{A MAF dataframe}

\item{sample.col}{Column name for sample IDs}

\item{gene.col}{Column name for gene symbols}

\item{value.var}{Column used as the value to aggregate}

\item{samples}{Vector of sample IDs to include; NULL keeps all samples present in the MAF}

\item{genes}{Vector of gene names to include; NULL keeps all genes present in the MAF}

\item{fun.aggregate}{Aggregation function applied per (sample, gene) cell}

\item{binarize}{If TRUE, convert aggregated counts to binary presence/absence}

\item{fill}{Value used for missing (sample, gene) combinations}
}
\value{
Numeric matrix (samples x genes) representing the gene alteration matrix.
}
\description{
\code{maf2gam()} takes a maf file and converts into gam
}
\examples{
data(luad_maf, package = "SelectSim")
small_maf <- luad_maf[
  luad_maf$Tumor_Sample_Barcode \%in\%
    unique(luad_maf$Tumor_Sample_Barcode)[1:5],
]
gam <- maf2gam(small_maf)
dim(gam)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_plot.R
\name{ridge_plot_ed_compare}
\alias{ridge_plot_ed_compare}
\title{Ridge plot comparing null-model distributions for two datasets}
\usage{
ridge_plot_ed_compare(result_df, obj1, obj2, name1, name2)
}
\arguments{
\item{result_df}{A data frame of gene pairs to display, with columns
\code{SFE_1}, \code{SFE_2}, \code{name}, \code{type}, \code{dataset1_w_overlap},
and \code{dataset2_w_overlap}.}

\item{obj1}{SelectX object for dataset 1 (\code{selectX()$obj}).}

\item{obj2}{SelectX object for dataset 2 (\code{selectX()$obj}).}

\item{name1}{Display label for dataset 1.}

\item{name2}{Display label for dataset 2.}
}
\value{
A ggplot2 ridge-plot object.
}
\description{
For each gene pair in \code{result_df}, overlays the null-model weighted-overlap
distributions from two separate \code{selectX} runs, allowing visual comparison
of evolutionary dependencies across cohorts or conditions.
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
r1 <- selectX(M = luad_run_data$M,
              sample.class = luad_run_data$sample.class,
              alteration.class = luad_run_data$alteration.class,
              n.cores = 1, min.freq = 10, n.permut = 10, verbose = FALSE)
r2 <- selectX(M = luad_run_data$M,
              sample.class = luad_run_data$sample.class,
              alteration.class = luad_run_data$alteration.class,
              n.cores = 1, min.freq = 10, n.permut = 10, verbose = FALSE)
common <- head(r1$result, 3)
common$dataset1_w_overlap <- common$w_overlap
common$dataset2_w_overlap <- common$w_overlap
ridge_plot_ed_compare(common, r1$obj, r2$obj, "Run1", "Run2")
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gam_utils.r
\name{mutation_type}
\alias{mutation_type}
\title{Mutation list object}
\usage{
mutation_type
}
\value{
A list containing the supported mutation-type classifications.
}
\description{
Mutation list object
}
\examples{
str(mutation_type)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gam_utils.r
\name{filter_maf_gene.name}
\alias{filter_maf_gene.name}
\title{Filter a MAF dataframe by gene name}
\usage{
filter_maf_gene.name(maf, genes, gene.col = "Hugo_Symbol", ...)
}
\arguments{
\item{maf}{A MAF dataframe}

\item{genes}{Vector of gene names to retain}

\item{gene.col}{Column name containing gene symbols}

\item{...}{Additional arguments passed to filter_maf_column}
}
\value{
Filtered MAF dataframe.
}
\description{
Filter a MAF dataframe by gene name
}
\examples{
data(luad_maf, package = "SelectSim")
filter_maf_gene.name(luad_maf, genes = c("TP53", "KRAS"))

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gam_utils.r
\name{GENIE_maf_schema}
\alias{GENIE_maf_schema}
\title{GENIE_maf_schema: schema for GENIE maf file to process the mutations}
\usage{
GENIE_maf_schema
}
\value{
A list defining the expected GENIE MAF column schema.
}
\description{
GENIE_maf_schema: schema for GENIE maf file to process the mutations
}
\examples{
str(GENIE_maf_schema)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gam_utils.r
\name{filter_maf_mutations}
\alias{filter_maf_mutations}
\title{Filter a MAF dataframe by specific gene-mutation combinations}
\usage{
filter_maf_mutations(
  maf,
  values,
  maf.col = c("Hugo_Symbol", "HGVSp_Short"),
  values.col = maf.col,
  ...
)
}
\arguments{
\item{maf}{A MAF dataframe}

\item{values}{Dataframe of allowed (gene, mutation) combinations}

\item{maf.col}{Columns in maf to join on}

\item{values.col}{Corresponding columns in values to join on}

\item{...}{Additional arguments passed to filter_maf_complex}
}
\value{
Filtered MAF dataframe containing only rows matching the allowed combinations.
}
\description{
Filter a MAF dataframe by specific gene-mutation combinations
}
\examples{
data(luad_maf, package = "SelectSim")
allowed <- data.frame(Hugo_Symbol  = c("TP53", "KRAS"),
                      HGVSp_Short  = c("p.R175H", "p.G12C"))
filter_maf_mutations(luad_maf, allowed)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_plot.R
\name{theme_Publication}
\alias{theme_Publication}
\title{A clean ggplot2 theme for publication-quality plots}
\usage{
theme_Publication(base_size = 14, base_family = "sans")
}
\arguments{
\item{base_size}{size of fonts}

\item{base_family}{type of font}
}
\value{
A ggplot2 theme object.
}
\description{
A clean ggplot2 theme for publication-quality plots
}
\examples{
library(ggplot2)
ggplot(data.frame(x = 1:3, y = 1:3), aes(x, y)) +
  geom_point() + theme_Publication()

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{variant_catalogue}
\alias{variant_catalogue}
\title{OncoKB v3.9 cancer genes}
\format{
A data frame
}
\usage{
data(variant_catalogue)
}
\value{
A data frame containing cancer-gene and variant annotations.
}
\description{
A dataframe cancer genes with missense mutation annotations
}
\examples{
data(variant_catalogue)
dim(variant_catalogue)
head(variant_catalogue)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{new.AMS}
\alias{new.AMS}
\title{Initialize an Alteration Matrix Stats (AMS) container}
\usage{
new.AMS(am)
}
\arguments{
\item{am}{The alteration matrix (checked for NULL)}
}
\value{
Empty AMS list object.
}
\description{
Initialize an Alteration Matrix Stats (AMS) container
}
\examples{
new.AMS(matrix(0, 2, 2))

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_create.r
\name{generateW_block}
\alias{generateW_block}
\title{Generate block-aware sample weight matrix}
\usage{
generateW_block(al, lambda, tau)
}
\arguments{
\item{al}{Alteration landscape object (from \code{new.AL.general}).}

\item{lambda}{Numeric penalty factor for the weight computation.}

\item{tau}{Numeric fold-change threshold below which no penalty is applied.}
}
\value{
List with \code{W_block} (per-block weight matrices), \code{W} (full
concatenated weight matrix), \code{W_median} (per-block median TMBs), and
\code{mean_TMB} (mean of block medians).
}
\description{
Computes a sample weight matrix that accounts for sample-class covariates
(blocks). Within each block the reference TMB is the block median; the
overall reference used by \code{generateW_mean_tmb} is the mean of those
block medians.
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
al <- new.AL.general(luad_run_data$M,
                     feat.covariates  = luad_run_data$alteration.class,
                     sample.covariates = luad_run_data$sample.class,
                     min.freq = 10)
generateW_block(al, lambda = 0.3, tau = 1)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{luad_run_data}
\alias{luad_run_data}
\title{Lung adenocarcinoma from TCGA cohort as SelectSim run object}
\format{
A named list with four elements:
\describe{
\item{M}{A named list containing:
\describe{
\item{M}{A named list of binary alteration matrices (genes x samples),
one per alteration type (e.g., \code{missense}, \code{truncating}).}
\item{tmb}{A named list of data frames, one per alteration type, each
with columns \code{sample} (character) and \code{mutation} (integer
TMB count).}
}
}
\item{sample.class}{Named character vector of sample-type annotations
(length = number of samples). Names are sample IDs.}
\item{alteration.class}{Named character vector of alteration-type annotations
(length = number of genes). Names are gene symbols.}
}
}
\usage{
data(luad_run_data)
}
\value{
A named list containing preprocessed LUAD input data for
\code{selectX()}.
}
\description{
Preprocessed TCGA LUAD data ready to pass directly to \code{selectX()}.
}
\examples{
data(luad_run_data)
names(luad_run_data)
str(luad_run_data, max.level = 1)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{r.effectSize}
\alias{r.effectSize}
\title{Compute effect sizes for null model permutations}
\usage{
r.effectSize(null_overlap, mean_mat, n.permut = 1000, n.cores = 1)
}
\arguments{
\item{null_overlap}{List of null model overlap matrices (one per permutation)}

\item{mean_mat}{Mean overlap matrix across all permutations}

\item{n.permut}{Number of permutations}

\item{n.cores}{Number of cores (currently unused; sequential only)}
}
\value{
List of effect size vectors, one per permutation.
}
\description{
Compute effect sizes for null model permutations
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
result  <- selectX(M = luad_run_data$M,
                   sample.class = luad_run_data$sample.class,
                   alteration.class = luad_run_data$alteration.class,
                   n.cores = 1, min.freq = 10, n.permut = 10,
                   verbose = FALSE)
null_ov  <- r.am.pairwise.alteration.overlap(result$obj$null,
                                             n.permut = result$obj$nSim)
mean_mat <- Reduce("+", null_ov) / result$obj$nSim
r.effectSize(null_ov, mean_mat, n.permut = result$obj$nSim)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{r.am.pairwise.alteration.overlap}
\alias{r.am.pairwise.alteration.overlap}
\title{Compute null overlap matrix}
\usage{
r.am.pairwise.alteration.overlap(null, n.permut, n.cores = 1)
}
\arguments{
\item{null}{The null model (list of simulated binary matrices)}

\item{n.permut}{Accepted for API compatibility; currently unused internally.}

\item{n.cores}{Accepted for API compatibility; currently unused internally.}
}
\value{
Overlap matrix summed across all permutations.
}
\description{
Compute null overlap matrix
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
result <- selectX(M = luad_run_data$M,
                  sample.class = luad_run_data$sample.class,
                  alteration.class = luad_run_data$alteration.class,
                  n.cores = 1, min.freq = 10, n.permut = 10,
                  verbose = FALSE)
r.am.pairwise.alteration.overlap(result$obj$null, n.permut = result$obj$nSim)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{add}
\alias{add}
\title{Sum a list of matrices element-wise}
\usage{
add(x)
}
\arguments{
\item{x}{List of matrices of identical dimensions}
}
\value{
Single matrix that is the element-wise sum of all matrices in x
}
\description{
Sum a list of matrices element-wise
}
\examples{
mats <- list(matrix(1:4, 2, 2), matrix(1:4, 2, 2))
add(mats)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{estimate_pairwise_p}
\alias{estimate_pairwise_p}
\title{Compute p-values for all gene pairs in a results table}
\usage{
estimate_pairwise_p(obs, exp, results, nSim)
}
\arguments{
\item{obs}{Observed pairwise overlap matrix}

\item{exp}{List of null model overlap matrices (one per permutation)}

\item{results}{Results data frame with SFE_1 and SFE_2 columns}

\item{nSim}{Number of permutations}
}
\value{
Vector of p-values, one per row in results.
}
\description{
Compute p-values for all gene pairs in a results table
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
result <- selectX(M = luad_run_data$M,
                  sample.class = luad_run_data$sample.class,
                  alteration.class = luad_run_data$alteration.class,
                  n.cores = 1, min.freq = 10, n.permut = 10,
                  verbose = FALSE, estimate_pairwise = TRUE)
head(result$result[, c("SFE_1","SFE_2","pairwise_p")])
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_create.r
\name{null_model_parallel}
\alias{null_model_parallel}
\title{Generating the null_simulation matrix}
\usage{
null_model_parallel(al, temp_mat, W, n.cores = 1, n.permut, seed = 42)
}
\arguments{
\item{al}{Alteration landscape object}

\item{temp_mat}{template matrices}

\item{W}{weight matrix}

\item{n.cores}{Number of cores}

\item{n.permut}{Number of simulations}

\item{seed}{Random seed}
}
\value{
List of simulated binary matrices (one per permutation)
}
\description{
Generating the null_simulation matrix
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
al       <- new.AL.general(luad_run_data$M,
                           feat.covariates  = luad_run_data$alteration.class,
                           sample.covariates = luad_run_data$sample.class,
                           min.freq = 10)
temp_obj <- template.obj.gen(al)
W        <- generateW_block(al, lambda = 0.3, tau = 1)
sims     <- null_model_parallel(al, temp_obj$temp_mat, W$W,
                                n.cores = 1, n.permut = 10)
length(sims)
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{am.pairwise.alteration.coverage}
\alias{am.pairwise.alteration.coverage}
\title{Compute pairwise alteration coverage statistics}
\usage{
am.pairwise.alteration.coverage(overlap_M, M.stats, w_overlap_M)
}
\arguments{
\item{overlap_M}{The pairwise overlap matrix}

\item{M.stats}{The alteration matrix stats (from am.stats)}

\item{w_overlap_M}{The weighted pairwise overlap matrix}
}
\value{
List with overlap and w_overlap sparse matrices.
}
\description{
Compute pairwise alteration coverage statistics
}
\examples{
am <- matrix(c(0,1,1,0,1,1), nrow = 2,
             dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
W  <- matrix(1, nrow = 2, ncol = 3,
             dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
ovlp  <- am.pairwise.alteration.overlap(am)
wovlp <- am.weight.pairwise.alteration.overlap(am, W)
stats <- am.stats(am)
am.pairwise.alteration.coverage(ovlp, stats, wovlp)

}
